### PUT YOUR OWN PATH TO DATA FOLDER BELOW IN "[Path]"
setwd("~/[Path]/Data")

# Needed Packages
#install.packages("ggplot2")
#install.packages("dplyr")
#install.packages("tidyr")
#install.packages("emmeans")
#install.packages("multcompView")
#install.packages("car")
#install.packages ("glmer")
#install.packages("RVAideMemoire")
#install.packages("pscl")

library(ggplot2)
library(stats)
library(lme4)
library(car)
library(multcomp)
library(MASS)
library(emmeans) # For estimated marginal means
library(multcompView) # for CLD display of EMM
library(AER) # for dispersion.test() for Poisson GLMs
library(RVAideMemoire) # for overdisp.glmer() for NB and Poisson GLMMs
library(pscl)

#########################################################################
#########################################################################
#########################################################################
#########################################################################
#########################################################################
# Virus Titers
### 2016: Intracolony assays
### 2017: Intercolony assays

## 2017
### BOS 2017 - Virus Titers

### AllViruses - With FoldChange 
#### (e.g. we make the standard curve match previous runs by assuming
#### the -1 dilution is actually the -2, as the meanCQ implies).
allvirus2017 <-read.csv("2017viruses.csv")
summary(allvirus2017)

colnames(allvirus2017) <- tolower(colnames(allvirus2017))
colnames(allvirus2017)
allvirus2017$round <- as.factor(allvirus2017$round) 
summary(allvirus2017)
levels(allvirus2017$treatment)[levels(allvirus2017$treatment)=="Virus"] <- "IAPV"
levels(allvirus2017$treatment)[levels(allvirus2017$treatment)=="Sugar"] <- "Control"
level_order <- c('Control', 'IAPV', 'dsRNA')

ggplot(allvirus2017, aes(x=factor(treatment, level = level_order), y=logmeansq, fill=treatment, alpha=0.2)) +
  facet_wrap(~target) +
  geom_violin()+theme_classic() +
  geom_jitter(shape=16, position=position_jitter(0.2)) +
  ylab("Log(Viral Genome Equivalents)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(allvirus2017, aes(x=factor(treatment, level = level_order), y=logmeansq, fill=treatment, alpha=0.2)) +
  facet_wrap(~target) +
  geom_violin()+theme_classic() +
  ylab("Log(Viral Genome Equivalents)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

virus17a <- ggplot(allvirus2017, aes(treatment,logmeansq, label = treatment, fill=treatment)) +
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "black") +
  geom_jitter(shape=16, position=position_jitter(0.2)) +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  facet_wrap(~target, nrow = 1) +
  labs(x="Treatment", y = "Intercolonial Assasys - Log(Viral Genome Equivalents)") +
  theme_classic()
virus17a

justIAPV2017 <- allvirus2017[ which(allvirus2017$target=='IAPV'),]  
summary(justIAPV2017)
iapv2017 <- glm(logmeansq~treatment, data=justIAPV2017)
summary(iapv2017)
# SigDiff in IAPV
library(multcomp)
ituk <- glht(iapv2017, linfct = mcp(treatment = "Tukey"))
summary(ituk)          # standard display
ituk.cld <- cld(ituk)
ituk.cld # letter-based display
plot(ituk.cld, ylab="IAPV-Log(meanVGE)")

justKBV2017 <- allvirus2017[ which(allvirus2017$target=='KBV'),]  
summary(justKBV2017)
kbv2017 <- glm(logmeansq~treatment, data=justKBV2017)
summary(kbv2017)
# No Diff in KBV
ktuk <- glht(kbv2017, linfct = mcp(treatment = "Tukey"))
summary(ktuk)          # standard display
ktuk.cld <- cld(ktuk)   # letter-based display
ktuk.cld
plot(ktuk.cld, ylab="KBV-Log(meanVGE)")


justDWV2017 <- allvirus2017[ which(allvirus2017$target=='DWV'),]
summary(justDWV2017)
dwv2017 <- glm(logmeansq~treatment, data=justDWV2017)
dwv2017a <- glmer(logmeansq~treatment+(1|round), data=justDWV2017)
anova(dwv2017, dwv2017a)
summary(dwv2017)
summary(dwv2017a)
#No diff in DWV
dtuk <- glht(dwv2017, linfct = mcp(treatment = "Tukey"))
summary(dtuk)          # standard display
dtuk.cld <- cld(dtuk)
dtuk.cld # letter-based display
plot(dtuk.cld, ylab="DWV-Log(meanVGE)")

dtuka <- glht(dwv2017a, linfct = mcp(treatment = "Tukey"))
summary(dtuka)          # standard display
dtuka.cld <- cld(dtuka)

#########################################################################
#########################################################################
## 2016-All Viruses
allvirus2016 <- read.csv("2016viruses.csv")
summary(allvirus2016)

colnames(allvirus2016) <- tolower(colnames(allvirus2016))
colnames(allvirus2016)

# Subset out the "baseline bees"
allvirus2016 <- allvirus2016[allvirus2016$treatment != "baseline", ]

levels(allvirus2016$treatment)[levels(allvirus2016$treatment)=="virus"] <- "IAPV"
levels(allvirus2016$treatment)[levels(allvirus2016$treatment)=="sugar"] <- "Control"
level_order <- c('Control', 'IAPV', 'dsRNA')
summary(allvirus2016)

ggplot(allvirus2016, aes(x=factor(treatment, level = level_order), y=logmeansq, fill=treatment, alpha=0.2)) +
  facet_wrap(~target) +
  geom_violin()+theme_classic() +
  geom_jitter(shape=16, position=position_jitter(0.2)) +
  ylab("Log(Viral Genome Equivalents)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(allvirus2016, aes(x=factor(treatment, level = level_order), y=logmeansq, fill=treatment, alpha=0.2)) +
  facet_wrap(~target) +
  geom_violin()+theme_classic() +
  ylab("Log(Viral Genome Equivalents)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

virus2016a <- ggplot(allvirus2016, aes(treatment,logmeansq, label = treatment, fill=treatment)) +
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "black") +
  geom_jitter(shape=16, position=position_jitter(0.2)) +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  facet_wrap(~target, nrow = 1) +
  labs(x="Treatment", y = "Intracolonial Assasys - Log(Viral Genome Equivalents)") +
  theme_classic()
virus2016a

# DWV
justDWV2016 <- allvirus2016[which(allvirus2016$target=='DWV'),]
summary(justDWV2016)
dwv2016 <- glm(logmeansq~treatment, data=justDWV2016)
summary(dwv2016)

qqnorm(justDWV2016$logmeansq)

dtuk <- glht(dwv2016, linfct = mcp(treatment = "Tukey"))
summary(dtuk)          # standard display
dtuk.cld <- cld(dtuk)
dtuk.cld # letter-based display
plot(dtuk.cld, ylab="DWV-Log(meanVGE)")


# IAPV
justIAPV2016 <- allvirus2016[ which(allvirus2016$target=='IAPV'),]
summary(justIAPV2016)
iapv2016 <- glm(logmeansq~treatment, data=justIAPV2016)
summary(iapv2016)

ituk <- glht(iapv2016, linfct = mcp(treatment = "Tukey"))
summary(ituk)          # standard display
ituk.cld <- cld(ituk)
ituk.cld # letter-based display
plot(ituk.cld, ylab="IAPV-Log(meanVGE)")


# KBV
justKBV2016 <- allvirus2016[ which(allvirus2016$target=='KBV'),]
summary(justKBV2016)
kbv2016 <- glm(logmeansq~treatment, data=justKBV2016)
summary(kbv2016)

ktuk <- glht(kbv2016, linfct = mcp(treatment = "Tukey"))
summary(ktuk)          # standard display
ktuk.cld <- cld(ktuk)
ktuk.cld # letter-based display
plot(ktuk.cld, ylab="KBV-Log(meanVGE)")

# SBV
justSBV2016 <- allvirus2016[ which(allvirus2016$target=='SBV'),]
summary(justSBV2016)
sbv2016 <- glm(logmeansq~treatment, data=justSBV2016)
summary(sbv2016)

stuk <- glht(sbv2016, linfct = mcp(treatment = "Tukey"))
summary(stuk)          # standard display
stuk.cld <- cld(stuk)
stuk.cld # letter-based display
plot(stuk.cld, ylab="SBV-Log(meanVGE)")

#########################################################################
#########################################################################
#########################################################################
#########################################################################
#########################################################################
# 2016 Intracolony Behaviors
dish2016 <- read.csv("2016behavior.csv") 

colnames(dish2016)
#Convert column names to lower case
colnames(dish2016) <- tolower(colnames(dish2016))
colnames(dish2016)
str(dish2016)
levels(dish2016$treatment)[levels(dish2016$treatment)=="Virus"] <- "IAPV"

#converts round to factor, not a number
dish2016$round <- as.factor(dish2016$round)
head(dish2016)
summary(dish2016)
str(dish2016)

levels(dish2016$treatment)[levels(dish2016$treatment)=="Virus"] <- "IAPV"
levels(dish2016$treatment)[levels(dish2016$treatment)=="Sugar"] <- "Control"
level_order <- c('Control', 'IAPV', 'dsRNA')
summary(dish2016)
########################################################
########################################################
########################################################
######################################################
######################################################
######################################################
# Counts for Focal bees
m1tre <- glmer(trophexp~treatment+(1|round), family = poisson(link = "log"), data=dish2016)
m2tre <- glm(trophexp~treatment, family = poisson(link = "log"), data=dish2016)
m3tre <- glm.nb(trophexp ~ treatment, data = dish2016)
m4tre <- glmer.nb(trophexp~treatment+(1|round), data=dish2016)
anova(m1tre, m2tre, m3tre, m4tre) 
# Model 4 is best AIC, but fails to converge
# Typical Poisson with RE (model 1), is next best.

overdisp.glmer(m1tre)
dispersiontest(m2tre)
odTest(m3tre)
overdisp.glmer(m4tre)

summary(m1tre)
treem <- emmeans(m1tre, pairwise ~ treatment)
treem
treemm <- emmeans(m1tre, "treatment")
treem.cld <- cld(treemm)
treem.cld

cetrophplot3 <- ggplot(dish2016, aes(x=treatment, y=trophexp, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Trophallaxis") +
  theme_classic()
cetrophplot3

# Beryl's Code
ggplot(dish2016, aes(x=factor(treatment, level = level_order), y=trophexp, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Trophallaxis")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#############################
m1trp <- glmer(trophpart~treatment+(1|round), family = poisson(link = "log"), data=dish2016)
m2trp <- glm(trophpart~treatment, family = poisson(link = "log"), data=dish2016)
m3trp <- glm.nb(trophpart ~ treatment, data = dish2016)
m4trp <- glmer.nb(trophpart~treatment+(1|round), data=dish2016)
anova(m1trp, m2trp, m3trp, m4trp) 
# Model 4 is best AIC, but fails to converge
# Typical Poisson with RE (model 1), is next best.
summary(m1trp)
trpem <- emmeans(m1trp, pairwise ~ treatment)
trpem
trpemm <- emmeans(m1trp, "treatment")
trpem.cld <- cld(trpemm)
trpem.cld

cetrophplot3 <- ggplot(dish2016, aes(x=treatment, y=trophpart, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Parnter Trophallaxis") +
  theme_classic()
cetrophplot3

ggplot(dish2016, aes(x=factor(treatment), y=trophpart, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Partner Trophallaxis")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#############################
#############################
m1anp <- glmer(antpart~treatment+(1|round), family = poisson(link = "log"), data=dish2016)
m2anp <- glm(antpart~treatment, family = poisson(link = "log"), data=dish2016)
m3anp <- glm.nb(antpart ~ treatment, data = dish2016)
m4anp <- glmer.nb(antpart~treatment+(1|round), data=dish2016)
anova(m1anp, m2anp, m3anp, m4anp) 
# Model 4 is best AIC

overdisp.glmer(m1anp)
dispersiontest(m2anp)
odTest(m3anp)
overdisp.glmer(m4anp)

summary(m4anp)
anpem <- emmeans(m4anp, pairwise ~ treatment)
anpem
anpemm <- emmeans(m4anp, "treatment")
anpem.cld <- cld(anpemm)
anpem.cld

ceantplot3 <- ggplot(dish2016, aes(x=treatment, y=antpart, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "black") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "black") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Antennation of Focal Bee") +
  theme_classic()
ceantplot3

ggplot(dish2016, aes(x=factor(treatment, level = level_order), y=antpart, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Partner Antennation")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(dish2016, aes(x=factor(treatment, level = level_order), y=antpart, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  ylab("Counts of Antennation of Focal")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(dish2016, aes(x=factor(treatment, level = level_order), y=antpart, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Antennation of Focal")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)
#############################
#############################
#############################
#############################
m1ste <- glmer(stillexp~treatment+(1|round), family = poisson(link = "log"), data=dish2016)
m2ste <- glm(stillexp~treatment, family = poisson(link = "log"), data=dish2016)
m3ste <- glm.nb(stillexp ~ treatment, data = dish2016)
m4ste <- glmer.nb(stillexp~treatment+(1|round), data=dish2016)
anova(m1ste, m2ste, m3ste, m4ste) 
# Model 4 fails to converge
# Model 3 has best AIC

overdisp.glmer(m1ste)
dispersiontest(m2ste)
odTest(m3ste)
overdisp.glmer(m4ste)

summary(m3ste)
steem <- emmeans(m3ste, pairwise ~ treatment)
steem
steemm <- emmeans(m3ste, "treatment")
steem.cld <- cld(steemm)
steem.cld

cestillplot3 <- ggplot(dish2016, aes(x=treatment, y=stillexp, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "black") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "black") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Focal Bee Inactivity") +
  theme_classic()
cestillplot3

ggplot(dish2016, aes(x=factor(treatment, level = level_order), y=stillexp, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  ylab("Counts of Focal Inactivity")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(dish2016, aes(x=factor(treatment, level = level_order), y=stillexp, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Focal Inactivity")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(dish2016, aes(x=factor(treatment), y=stillexp, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Focal Inactivity")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################################################
#########################################################################
#########################################################################
#########################################################################
#########################################################################
# 2017 Intercolony Behaviors
#### Read in the Data
cage2017 <- (read.csv("2017behavior.csv")) #reads in behavioral data
summary(cage2017)

colnames(cage2017)
#Convert column names to lower case
colnames(cage2017) <- tolower(colnames(cage2017))
colnames(cage2017)
levels(cage2017$treatment)[levels(cage2017$treatment)=="Virus"] <- "IAPV"
level_order <- c('Control', 'IAPV', 'dsRNA')
summary(cage2017)

cage2017$round <- as.factor(cage2017$round)
cage2017$receivercol <- as.factor(cage2017$receivercol)
summary(cage2017)

#adds new column with total counts of trophallaxis
cage2017$totaltroph <- cage2017$troph+cage2017$trophwithfocal
summary(cage2017)
#adds new column wherein we observe the proportion of trophallaxis
# that is conducted with the focal
cage2017$propfoctro <-(100*(cage2017$trophwithfocal/cage2017$totaltroph))
summary(cage2017)
#converts n/a to 0 in this column 
# (for examples where no trophallaxis was observed)
cage2017$propfoctro[is.na(cage2017$propfoctro)]<-0
summary(cage2017)

#########################################
#########################################
#Aggression with/to focal
m1ra <- glmer(aggr~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2ra <- glmer(aggr~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3ra <- glmer(aggr~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4ra <- glm(aggr~treatment, family = poisson(link = "log"), data=cage2017)
m5ra <- glm.nb(aggr ~ treatment, data = cage2017)
m6ra <- glmer.nb(aggr~treatment+(1|round)+(1|receivercol), data=cage2017)
m7ra <- glmer.nb(aggr~treatment+(1|round), data=cage2017)
m8ra <- glmer.nb(aggr~treatment+(1|receivercol), data=cage2017)
anova(m1ra17, m2ra, m3ra, m4ra, m5ra, m6ra, m7ra, m8ra)
summary(m5ra) 
# Model 7 is best fit, but fails to converge
# Model 5 is next best

overdisp.glmer(m1ra)
overdisp.glmer(m2ra)
overdisp.glmer(m3ra)
dispersiontest(m4ra)
odTest(m5ra)
overdisp.glmer(m6ra)
overdisp.glmer(m7ra)
overdisp.glmer(m8ra)

# Estimated marginal means
agem <- emmeans(m5ra, pairwise ~ treatment)
agem
agl <- as.list(ref_grid(m5ra))
agemm <- as.emmGrid(agl)
agem2 <- emmeans(agemm, "treatment")
agem.cld <- cld(agem2)
agem.cld
agemmplot<- plot(agem.cld,ylab="Counts Of Aggression to Focal", levels = level_order, colors = "blue")
agemmplot

aggrplot <- ggplot(cage2017, aes(x=treatment, y=aggr, color=treatment, fill=treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(), stat="identity") +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Total Aggression Counts") +
  theme_classic()
aggrplot

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=aggr, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Total Counts of Receiver Aggression")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
## Focal DEATH
dof <- glmer(deathoffocal~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
summary(dof)
dof2 <- glm(focaldeath~treatment, family = poisson(link = "log"), data=cage2017)
summary(dof2)
## Superficial analysis says there is big difference between Treatments
## when round is not included (has 20 point lower AIC if round is incl.)

########################################
#########################################
# Buzzing
m1bz <- glmer(buzzing~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2bz <- glmer(buzzing~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3bz <- glmer(buzzing~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4bz <- glm(buzzing~treatment, family = poisson(link = "log"), data=cage2017)
m5bz <- glm.nb(buzzing ~ treatment, data = cage2017)
m6bz <- glmer.nb(buzzing~treatment+(1|round)+(1|receivercol), data=cage2017)
m7bz <- glmer.nb(buzzing~treatment+(1|round), data=cage2017)
m8bz <- glmer.nb(buzzing~treatment+(1|receivercol), data=cage2017)
anova(m1bz, m2bz, m3bz, m4bz, m5bz, m6bz, m7bz, m8bz)
summary(m5bz)

overdisp.glmer(m1bz)
overdisp.glmer(m2bz)
overdisp.glmer(m3bz)
dispersiontest(m4bz)
odTest(m5bz)
overdisp.glmer(m6bz)
overdisp.glmer(m7bz)
overdisp.glmer(m8bz)

# Estimated marginal means
bzem <- emmeans(m5bz, pairwise ~ treatment)
bzem
bzl <- as.list(ref_grid(m5bz))
bzemm <- as.emmGrid(bzl)
bzem2 <- emmeans(bzemm, "treatment")
bzem.cld <- cld(bzem2)
bzem.cld
bzemmplot<- plot(bzem.cld,ylab="Counts Of Buzzing")
bzemmplot

ggplot(cage2017, aes(x=factor(treatment), y=buzzing, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  ylab("Counts of Receiver Buzzing")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=buzzing, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Receiver Buzzing")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Stinging
m1st <- glmer(stinging~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2st <- glmer(stinging~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3st <- glmer(stinging~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4st <- glm(stinging~treatment, family = poisson(link = "log"), data=cage2017)
m5st <- glm.nb(stinging ~ treatment, data = cage2017)
m6st <- glmer.nb(stinging~treatment+(1|round)+(1|receivercol), data=cage2017)
m7st <- glmer.nb(stinging~treatment+(1|round), data=cage2017)
m8st <- glmer.nb(stinging~treatment+(1|receivercol), data=cage2017)
anova(m1st, m2st, m3st, m4st, m5st, m6st, m7st, m8st)
summary(m4st)

overdisp.glmer(m1st)
overdisp.glmer(m2st)
overdisp.glmer(m3st)
dispersiontest(m4st)
odTest(m5st)
overdisp.glmer(m6st)
overdisp.glmer(m7st)
overdisp.glmer(m8st)

# Estimated marginal means
stem <- emmeans(m5st, pairwise ~ treatment)
stem
stl <- as.list(ref_grid(m5st))
stemm <- as.emmGrid(stl)
stem2 <- emmeans(stemm, "treatment")
stem.cld <- cld(stem2)
stem.cld
stemmplot<- plot(stem.cld,ylab="Counts Of Buzzing")
stemmplot

stingplot <- ggplot(cage2017, aes(x=treatment, y=stinging, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Stinging") +
  theme_classic()
stingplot

ggplot(cage2017, aes(x=factor(treatment), y=stinging, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  ylab("Counts of Stinging")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=stinging, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Stinging")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Biting
m1bt <- glmer(biting~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2bt <- glmer(biting~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3bt <- glmer(biting~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4bt <- glm(biting~treatment, family = poisson(link = "log"), data=cage2017)
m5bt <- glm.nb(biting ~ treatment, data = cage2017)
m6bt <- glmer.nb(biting~treatment+(1|round)+(1|receivercol), data=cage2017)
m7bt <- glmer.nb(biting~treatment+(1|round), data=cage2017)
m8bt <- glmer.nb(biting~treatment+(1|receivercol), data=cage2017)
anova(m1bt, m2bt, m3bt, m4bt, m5bt, m6bt, m7bt, m8bt)
summary(m7bt)

overdisp.glmer(m1bt)
overdisp.glmer(m2bt)
overdisp.glmer(m3bt)
dispersiontest(m4bt)
odTest(m5bt)
overdisp.glmer(m6bt)
overdisp.glmer(m7bt)
overdisp.glmer(m8bt)

# Estimated marginal means
btem <- emmeans(m7bt, pairwise ~ treatment)
btem
btl <- as.list(ref_grid(m7bt))
btemm <- as.emmGrid(btl)
btem2 <- emmeans(btemm, "treatment")
btem.cld <- cld(btem2)
btem.cld
btemmplot<- plot(btem.cld,ylab="Counts Of Biting")
btemmplot

bitplot <- ggplot(cage2017, aes(x=treatment, y=biting, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of biting") +
  theme_classic()
bitplot

ggplot(cage2017, aes(x=factor(treatment), y=biting, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  ylab("Counts of Biting")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=biting, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Biting")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Chasing
m1ch <- glmer(chasing~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2ch <- glmer(chasing~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3ch <- glmer(chasing~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4ch <- glm(chasing~treatment, family = poisson(link = "log"), data=cage2017)
m5ch <- glm.nb(chasing ~ treatment, data = cage2017)
m6ch <- glmer.nb(chasing~treatment+(1|round)+(1|receivercol), data=cage2017)
m7ch <- glmer.nb(chasing~treatment+(1|round), data=cage2017)
m8ch <- glmer.nb(chasing~treatment+(1|receivercol), data=cage2017)
anova(m1ch, m2ch, m3ch, m4ch, m5ch, m6ch, m7ch, m8ch)
summary(m7ch)

overdisp.glmer(m1ch)
overdisp.glmer(m2ch)
overdisp.glmer(m3ch)
dispersiontest(m4ch)
odTest(m5ch)
overdisp.glmer(m6ch)
overdisp.glmer(m7ch)
overdisp.glmer(m8ch)

# Estimated marginal means
chem <- emmeans(m7ch, pairwise ~ treatment)
chem
chl <- as.list(ref_grid(m7ch))
chemm <- as.emmGrid(chl)
chem2 <- emmeans(chemm, "treatment")
chem.cld <- cld(chem2)
chem.cld
chemmplot<- plot(chem.cld,ylab="Counts Of Chasing")
chemmplot

chaseplot <- ggplot(cage2017, aes(x=treatment, y=chasing, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of chasing") +
  theme_classic()
chaseplot

ggplot(cage2017, aes(x=factor(treatment), y=chasing, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  ylab("Counts of Chasing")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=chasing, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Chasing")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Allo Grooming
m1al <- glmer(allo~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2al <- glmer(allo~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3al <- glmer(allo~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4al <- glm(allo~treatment, family = poisson(link = "log"), data=cage2017)
m5al <- glm.nb(allo ~ treatment, data = cage2017)
m6al <- glmer.nb(allo~treatment+(1|round)+(1|receivercol), data=cage2017)
m7al <- glmer.nb(allo~treatment+(1|round), data=cage2017)
m8al <- glmer.nb(allo~treatment+(1|receivercol), data=cage2017)
anova(m1al, m2al, m3al, m4al, m5al, m6al, m7al, m8al)
summary(m5al)

overdisp.glmer(m1al)
overdisp.glmer(m2al)
overdisp.glmer(m3al)
dispersiontest(m4al)
odTest(m5al)
overdisp.glmer(m6al)
overdisp.glmer(m7al)
overdisp.glmer(m8al)

# Estimated marginal means
alem <- emmeans(m5al, pairwise ~ treatment)
alem
all <- as.list(ref_grid(m5al))
alemm <- as.emmGrid(all)
alem2 <- emmeans(alemm, "treatment")
alem.cld <- cld(alem2)
alem.cld
alemmplot<- plot(alem.cld,ylab="Counts Of alasing")
alemmplot

alloplot <- ggplot(cage2017, aes(x=treatment, y=allo, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Allo-grooming of Focal") +
  theme_classic()
alloplot

ggplot(cage2017, aes(x=factor(treatment), y=allo, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  ylab("Counts of Focal Allogrooming")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=allo, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Allogrooming Focal")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Total Troph
m1tt <- glmer(totaltroph~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2tt <- glmer(totaltroph~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3tt <- glmer(totaltroph~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4tt <- glm(totaltroph~treatment, family = poisson(link = "log"), data=cage2017)
m5tt <- glm.nb(totaltroph ~ treatment, data = cage2017)
m6tt <- glmer.nb(totaltroph~treatment+(1|round)+(1|receivercol), data=cage2017)
m7tt <- glmer.nb(totaltroph~treatment+(1|round), data=cage2017)
m8tt <- glmer.nb(totaltroph~treatment+(1|receivercol), data=cage2017)
anova(m1tt, m2tt, m3tt, m4tt, m5tt, m6tt, m7tt, m8tt)
summary(m5tt)

overdisp.glmer(m1tt)
overdisp.glmer(m2tt)
overdisp.glmer(m3tt)
dispersiontest(m4tt)
odTest(m5tt)
overdisp.glmer(m6tt)
overdisp.glmer(m7tt)
overdisp.glmer(m8tt)

# Estimated marginal means
ttem <- emmeans(m5tt, pairwise ~ treatment)
ttem
ttl <- as.list(ref_grid(m5tt))
ttemm <- as.emmGrid(ttl)
ttem2 <- emmeans(ttemm, "treatment")
ttem.cld <- cld(ttem2)
ttem.cld
ttemmplot<- plot(ttem.cld,ylab="Counts Of Trophallaxis (Total)")
ttemmplot

totaltrophplot <- ggplot(cage2017, aes(x=treatment, y=totaltroph, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Trophallaxis (Total)") +
  theme_classic()
totaltrophplot

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=totaltroph, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Total Counts of Trophallaxis")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Troph with Focal
m1tf17 <- glmer(trophwithfocal~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2tf <- glmer(trophwithfocal~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3tf <- glmer(trophwithfocal~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4tf <- glm(trophwithfocal~treatment, family = poisson(link = "log"), data=cage2017)
m5tf <- glm.nb(trophwithfocal ~ treatment, data = cage2017)
m6tf <- glmer.nb(trophwithfocal~treatment+(1|round)+(1|receivercol), data=cage2017)
m7tf <- glmer.nb(trophwithfocal~treatment+(1|round), data=cage2017)
m8tf <- glmer.nb(trophwithfocal~treatment+(1|receivercol), data=cage2017)
anova(m1tf17, m2tf, m3tf, m4tf, m5tf, m6tf, m7tf, m8tf)
summary(m5tf)

overdisp.glmer(m1tf)
overdisp.glmer(m2tf)
overdisp.glmer(m3tf)
dispersiontest(m4tf)
odTest(m5tf)
overdisp.glmer(m6tf)
overdisp.glmer(m7tf)
overdisp.glmer(m8tf)

# Estimated marginal means
tfem <- emmeans(m5tf, pairwise ~ treatment)
tfem
tfl <- as.list(ref_grid(m5tf))
tfemm <- as.emmGrid(tfl)
tfem2 <- emmeans(tfemm, "treatment")
tfem.cld <- cld(tfem2)
tfem.cld
tfemmplot<- plot(tfem.cld,ylab="Counts Of Trophallaxis (with Focal)")
tfemmplot

trophwithfocalplot <- ggplot(cage2017, aes(x=treatment, y=trophwithfocal, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Trophallaxis (with Focal)") +
  theme_classic()
trophwithfocalplot

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=trophwithfocal, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Trophallaxis with Focal")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

########################################
#########################################
# Troph with Conspecifics
m1tc <- glmer(troph~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2tc <- glmer(troph~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3tc <- glmer(troph~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4tc <- glm(troph~treatment, family = poisson(link = "log"), data=cage2017)
m5tc <- glm.nb(troph ~ treatment, data = cage2017)
m6tc <- glmer.nb(troph~treatment+(1|round)+(1|receivercol), data=cage2017)
m7tc <- glmer.nb(troph~treatment+(1|round), data=cage2017)
m8tc <- glmer.nb(troph~treatment+(1|receivercol), data=cage2017)
anova(m1tc, m2tc, m3tc, m4tc, m5tc, m6tc, m7tc, m8tc)
summary(m5tc)

overdisp.glmer(m1tc)
overdisp.glmer(m2tc)
overdisp.glmer(m3tc)
dispersiontest(m4tc)
odTest(m5tc)
overdisp.glmer(m6tc)
overdisp.glmer(m7tc)
overdisp.glmer(m8tc)

# Estimated marginal means
tcem <- emmeans(m5tc, pairwise ~ treatment)
tcem
tcl <- as.list(ref_grid(m5tc))
tcemm <- as.emmGrid(tcl)
tcem2 <- emmeans(tcemm, "treatment")
tcem.cld <- cld(tcem2)
tcem.cld
tcemmplot<- plot(tcem.cld,ylab="Counts Of Trophallaxis (with Conspecifics)")
tcemmplot

trophplot <- ggplot(cage2017, aes(x=treatment, y=troph, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Trophallaxis (with Sisters)") +
  theme_classic()
trophplot

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=troph, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Trophallaxis with Sisters")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Antennation
m1an <- glmer(ant~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2an <- glmer(ant~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3an <- glmer(ant~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4an <- glm(ant~treatment, family = poisson(link = "log"), data=cage2017)
m5an <- glm.nb(ant ~ treatment, data = cage2017)
m6an <- glmer.nb(ant~treatment+(1|round)+(1|receivercol), data=cage2017)
m7an <- glmer.nb(ant~treatment+(1|round), data=cage2017)
m8an <- glmer.nb(ant~treatment+(1|receivercol), data=cage2017)
anova(m1an, m2an, m3an, m4an, m5an, m6an, m7an, m8an) 
summary(m6an)

overdisp.glmer(m1an)
overdisp.glmer(m2an)
overdisp.glmer(m3an)
dispersiontest(m4an)
odTest(m5an)
overdisp.glmer(m6an)
overdisp.glmer(m7an)
overdisp.glmer(m8an)

antem <- emmeans(m6an, pairwise ~ treatment)
antem
antemm <- emmeans(m6an, "treatment")
antem.cld <- cld(antemm)
antem.cld

antplot <- ggplot(cage2017, aes(x=treatment, y=ant, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Focal Antennation") +
  theme_classic()
antplot

ggplot(cage2017, aes(x=factor(treatment, level = level_order), y=ant, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Antennation")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

#########################################
#########################################
# Self Gooming
m1sf <- glmer(selfgroom~treatment+(1|round)+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m2sf <- glmer(selfgroom~treatment+(1|receivercol), family = poisson(link = "log"), data=cage2017)
m3sf <- glmer(selfgroom~treatment+(1|round), family = poisson(link = "log"), data=cage2017)
m4sf <- glm(selfgroom~treatment, family = poisson(link = "log"), data=cage2017)
m5sf <- glm.nb(selfgroom ~ treatment, data = cage2017)
m6sf <- glmer.nb(selfgroom~treatment+(1|round)+(1|receivercol), data=cage2017)
m7sf <- glmer.nb(selfgroom~treatment+(1|round), data=cage2017)
m8sf <- glmer.nb(selfgroom~treatment+(1|receivercol), data=cage2017)
anova(m1sf, m2sf, m3sf, m4sf, m5sf, m6sf, m7sf, m8sf) 
summary(m6sf)

overdisp.glmer(m1sf)
overdisp.glmer(m2sf)
overdisp.glmer(m3sf)
dispersiontest(m4sf)
odTest(m5sf)
overdisp.glmer(m6sf)
overdisp.glmer(m7sf)
overdisp.glmer(m8sf)

sfem <- emmeans(m6sf, pairwise ~ treatment)
sfem
sfemm <- emmeans(m6sf, "treatment")
sfem.cld <- cld(sfemm)
sfem.cld

selfgroomplot <- ggplot(cage2017, aes(x=treatment, y=selfgroom, color=treatment, fill=treatment)) + 
  geom_violin() + 
  stat_summary(fun.y=mean, geom="point", size=2, color = "red") +
  stat_summary(fun.data = mean_se, geom = "errorbar", color = "red") +
  scale_fill_manual(values=c("palegreen", "lightskyblue", "purple")) +
  scale_color_manual(values=c("palegreen", "lightskyblue", "purple")) +
  labs(x="Treatment", y = "Counts of Self-grooming") +
  theme_classic()
selfgroomplot

ggplot(cage2017, aes(x=factor(treatment), y=selfgroom, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Counts of Self-grooming")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)
