# 2017 BOS Focal Bees - Hanks Lab (2018) GCMS Results
# Analysis of individual compounds
setwd("~/[Path to Data Folder]/Data")

library(ggplot2) # graphics
library(stats) # stats  
library(lme4) # GLMM
library(multcomp) # Tukeys

## Standard Error Function
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}

####################################################################
### Use the "All compounds" data sets; the bee-only compounds contain
### the same information, but fewer compounds.

# acppa = ALL compounds, Percentage peak area
acppa <- read.csv("2017_ALLCompounds_PerPeakArea.csv", na.string="na", header=T);

#Convert column names to lower case
colnames(acppa) <- tolower(colnames(acppa))
colnames(acppa)
View(acppa)

# Rename "dsRNA" to "sham" for clarity
levels(acppa$treatment)[levels(acppa$treatment)=="Virus"] <- "IAPV"
##################################################################
### Compare percent peak area (pCompound) across compounds. 
library(multcomp) #for Tukey tests

phentriaconteneglm<- glm(phentriacontene~treatment, data=acppa)
summary(phentriaconteneglm)

phentriacontenetuk <- glht(phentriaconteneglm, linfct = mcp(treatment = "Tukey"))
summary(phentriacontenetuk)          # standard display
phentriacontenetuk.cld <- cld(phentriacontenetuk)   # letter-based display
phentriacontenetuk.cld
plot(phentriacontenetuk.cld, ylab="pHentriacontene")


pmethylhentriacontaneglm<- glm(pmethylhentriacontane~treatment, data=acppa)
summary(pmethylhentriacontaneglm)

pmethylhentriacontanetuk <- glht(pmethylhentriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylhentriacontanetuk)          # standard display
pmethylhentriacontanetuk.cld <- cld(pmethylhentriacontanetuk)   # letter-based display
pmethylhentriacontanetuk.cld
plot(pmethylhentriacontanetuk.cld, ylab="pMethylhentriacontane")

pmethylheptacosaneglm<- glm(pmethylheptacosane~treatment, data=acppa)
summary(pmethylheptacosaneglm)

pmethylheptacosanetuk <- glht(pmethylheptacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylheptacosanetuk)          # standard display
pmethylheptacosanetuk.cld <- cld(pmethylheptacosanetuk)   # letter-based display
pmethylheptacosanetuk.cld
plot(pmethylheptacosanetuk.cld, ylab="pMethylheptacosane")

#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = pmethylheptacosane ~ treatment, data = acppa)

#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0  0.09284    0.09309   0.997    0.578  
#Virus - Control == 0 -0.10516    0.09434  -1.115    0.505  
#Virus - dsRNA == 0   -0.19799    0.08800  -2.250    0.063 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)

pmethyhep <- summarySE(acppa, measurevar="pmethylheptacosane", groupvars=c("treatment"))
head(pmethyhep)
pmethyhepplot <- ggplot(pmethyhep, aes(treatment, pmethylheptacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Control", "Sham", "Virus"), values=c("lightskyblue", "palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=pmethylheptacosane-se, ymax=pmethylheptacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
pmethyhepplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Methyl-Heptacosane") 
pmethyhepplot

ggplot(acppa, aes(x=factor(treatment), y=pmethylheptacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Methyl-Heptacosane")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pmethylnonacosaneglm<- glm(pmethylnonacosane~treatment, data=acppa)
summary(pmethylnonacosaneglm)

pmethylnonacosanetuk <- glht(pmethylnonacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylnonacosanetuk)          # standard display
pmethylnonacosanetuk.cld <- cld(pmethylnonacosanetuk)   # letter-based display
pmethylnonacosanetuk.cld
plot(pmethylnonacosanetuk.cld, ylab="pMethylnonacosane")

#
#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = pmethylnonacosane ~ treatment, data = acppa)

#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0   0.5855     0.3830   1.529    0.277  
#Virus - Control == 0  -0.4214     0.3881  -1.086    0.523  
#Virus - dsRNA == 0    -1.0070     0.3621  -2.781    0.015 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)

pmethylnonacosane <- summarySE(acppa, measurevar="pmethylnonacosane", groupvars=c("treatment"))
head(pmethylnonacosane)
pmethylnonacosaneplot <- ggplot(pmethylnonacosane, aes(treatment, pmethylnonacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=pmethylnonacosane-se, ymax=pmethylnonacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
pmethylnonacosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Methyl-Nonacosane") 
pmethylnonacosaneplot

ggplot(acppa, aes(x=factor(treatment), y=pmethylnonacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Methyl-nonacosane")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pmethyltriacontaneglm<- glm(pmethyltriacontane~treatment, data=acppa)
summary(pmethyltriacontaneglm)

pmethyltriacontanetuk <- glht(pmethyltriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(pmethyltriacontanetuk)          # standard display
pmethyltriacontanetuk.cld <- cld(pmethyltriacontanetuk)   # letter-based display
pmethyltriacontanetuk.cld
plot(pmethyltriacontanetuk.cld, ylab="pmethyltriacontane")

pdcarvoneglm<- glm(pdcarvone~treatment, data=acppa)
summary(pdcarvoneglm)

pdcarvonetuk <- glht(pdcarvoneglm, linfct = mcp(treatment = "Tukey"))
summary(pdcarvonetuk)          # standard display
pdcarvonetuk.cld <- cld(pdcarvonetuk)   # letter-based display
pdcarvonetuk.cld
plot(pdcarvonetuk.cld, ylab="pdcarvone")

pdlimoneneglm<- glm(pdlimonene~treatment, data=acppa)
summary(pdlimoneneglm)

pdlimonenetuk <- glht(pdlimoneneglm, linfct = mcp(treatment = "Tukey"))
summary(pdlimonenetuk)          # standard display
pdlimonenetuk.cld <- cld(pdlimonenetuk)   # letter-based display
pdlimonenetuk.cld
plot(pdlimonenetuk.cld, ylab="pdlimonene")

pdecanalglm<- glm(pdecanal~treatment, data=acppa)
summary(pdecanalglm)

pdecanaltuk <- glht(pdecanalglm, linfct = mcp(treatment = "Tukey"))
summary(pdecanaltuk)          # standard display
pdecanaltuk.cld <- cld(pdecanaltuk)   # letter-based display
pdecanaltuk.cld
plot(pdecanaltuk.cld, ylab="pdecanal")

pdocosaneglm<- glm(pdocosane~treatment, data=acppa)
summary(pdocosaneglm)

pdocosanetuk <- glht(pdocosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pdocosanetuk)          # standard display
pdocosanetuk.cld <- cld(pdocosanetuk)   # letter-based display
pdocosanetuk.cld
plot(pdocosanetuk.cld, ylab="pdocosane")

peicosaneglm<- glm(peicosane~treatment, data=acppa)
summary(peicosaneglm)

peicosanetuk <- glht(peicosaneglm, linfct = mcp(treatment = "Tukey"))
summary(peicosanetuk)          # standard display
peicosanetuk.cld <- cld(peicosanetuk)   # letter-based display
peicosanetuk.cld
plot(peicosanetuk.cld, ylab="peicosane")

pheneicosane1glm<- glm(pheneicosane1~treatment, data=acppa)
summary(pheneicosane1glm)

pheneicosane1tuk <- glht(pheneicosane1glm, linfct = mcp(treatment = "Tukey"))
summary(pheneicosane1tuk)          # standard display
pheneicosane1tuk.cld <- cld(pheneicosane1tuk)   # letter-based display
pheneicosane1tuk.cld
plot(pheneicosane1tuk.cld, ylab="pheneicosane1")

#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = pheneicosane1 ~ treatment, data = acppa)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0  -3.0200     1.3663  -2.210   0.0694 .
#Virus - Control == 0  -2.6118     1.3847  -1.886   0.1425  
#Virus - dsRNA == 0     0.4083     1.2917   0.316   0.9464  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#Control   dsRNA   Virus 
#"a"     "a"     "a" 

pheneicosane1 <- summarySE(acppa, measurevar="pheneicosane1", groupvars=c("treatment"))
head(pheneicosane1)
pheneicosane1plot <- ggplot(pheneicosane1, aes(treatment, pheneicosane1, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=pheneicosane1-se, ymax=pheneicosane1+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
pheneicosane1plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Heneicosane1") 

ggplot(acppa, aes(x=factor(treatment), y=pheneicosane1, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Heneicosane 1")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pheneicosane2glm<- glm(pheneicosane2~treatment, data=acppa)
summary(pheneicosane2glm)

pheneicosane2tuk <- glht(pheneicosane2glm, linfct = mcp(treatment = "Tukey"))
summary(pheneicosane2tuk)          # standard display
pheneicosane2tuk.cld <- cld(pheneicosane2tuk)   # letter-based display
pheneicosane2tuk.cld
plot(pheneicosane2tuk.cld, ylab="pheneicosane2")

pheneicoseneglm<- glm(pheneicosene~treatment, data=acppa)
summary(pheneicoseneglm)

pheneicosenetuk <- glht(pheneicoseneglm, linfct = mcp(treatment = "Tukey"))
summary(pheneicosenetuk)          # standard display
pheneicosenetuk.cld <- cld(pheneicosenetuk)   # letter-based display
pheneicosenetuk.cld
plot(pheneicosenetuk.cld, ylab="pheneicosene")

phentriacontaneglm<- glm(phentriacontane~treatment, data=acppa)
summary(phentriacontaneglm)

phentriacontanetuk <- glht(phentriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(phentriacontanetuk)          # standard display
phentriacontanetuk.cld <- cld(phentriacontanetuk)   # letter-based display
phentriacontanetuk.cld
plot(phentriacontanetuk.cld, ylab="phentriacontane")

pheptacosaneglm<- glm(pheptacosane~treatment, data=acppa)
summary(pheptacosaneglm)

pheptacosanetuk <- glht(pheptacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pheptacosanetuk)          # standard display
pheptacosanetuk.cld <- cld(pheptacosanetuk)   # letter-based display
pheptacosanetuk.cld
plot(pheptacosanetuk.cld, ylab="pheptacosane")

pheptadecaneglm<- glm(pheptadecane~treatment, data=acppa)
summary(pheptadecaneglm)

pheptadecanetuk <- glht(pheptadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(pheptadecanetuk)          # standard display
pheptadecanetuk.cld <- cld(pheptadecanetuk)   # letter-based display
pheptadecanetuk.cld
plot(pheptadecanetuk.cld, ylab="pheptadecane")

phexacosaneglm<- glm(phexacosane~treatment, data=acppa)
summary(phexacosaneglm)

phexacosanetuk <- glht(phexacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(phexacosanetuk)          # standard display
phexacosanetuk.cld <- cld(phexacosanetuk)   # letter-based display
phexacosanetuk.cld
plot(phexacosanetuk.cld, ylab="phexacosane")

phexadecenoicacidglm<- glm(phexadecenoicacid~treatment, data=acppa)
summary(phexadecenoicacidglm)

phexadecenoicacidtuk <- glht(phexadecenoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(phexadecenoicacidtuk)          # standard display
phexadecenoicacidtuk.cld <- cld(phexadecenoicacidtuk)   # letter-based display
phexadecenoicacidtuk.cld
plot(phexadecenoicacidtuk.cld, ylab="phexadecenoicacid") # Change to hexadecenoic acid, 2019
# Difference in Hexadecenoic acid
#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = phexadecenoicacid ~ treatment, data = acppa)

#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
# Sham - Control == 0   0.08526    0.16585   0.514   0.8644  
# Virus - Control == 0  0.42581    0.16808   2.533   0.0304 *
# Virus - Sham == 0     0.34055    0.15679   2.172   0.0759 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)

#> phexadecenoicacidtuk.cld <- cld(phexadecenoicacidtuk)   # letter-based display
#> phexadecenoicacidtuk.cld
#Control    Sham   Virus 
#"a"    "ab"     "b" 

phexadecenoicacid <- summarySE(acppa, measurevar="phexadecenoicacid", groupvars=c("treatment"))
head(phexadecenoicacid)
phexadecenoicacidplot <- ggplot(phexadecenoicacid, aes(treatment, phexadecenoicacid, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=phexadecenoicacid-se, ymax=phexadecenoicacid+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
phexadecenoicacidplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Hexadecenoic Acid") 

ggplot(acppa, aes(x=factor(treatment), y=phexadecenoicacid, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Hexadecenoic Acid")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)


phexadecanoicacidglm<- glm(phexadecanoicacid~treatment, data=acppa)
summary(phexadecanoicacidglm)

phexadecanoicacidtuk <- glht(phexadecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(phexadecanoicacidtuk)          # standard display
phexadecanoicacidtuk.cld <- cld(phexadecanoicacidtuk)   # letter-based display
phexadecanoicacidtuk.cld
plot(phexadecanoicacidtuk.cld, ylab="phexadecanoicacid")



phexadecanoicacidmethylester1glm<- glm(phexadecanoicacidmethylester1~treatment, data=acppa)
summary(phexadecanoicacidmethylester1glm)

phexadecanoicacidmethylester1tuk <- glht(phexadecanoicacidmethylester1glm, linfct = mcp(treatment = "Tukey"))
summary(phexadecanoicacidmethylester1tuk)          # standard display
phexadecanoicacidmethylester1tuk.cld <- cld(phexadecanoicacidmethylester1tuk)   # letter-based display
phexadecanoicacidmethylester1tuk.cld
plot(phexadecanoicacidmethylester1tuk.cld, ylab="phexadecanoicacidmethylester1")

phexadecanoicacidmethylester2glm<- glm(phexadecanoicacidmethylester2~treatment, data=acppa)
summary(phexadecanoicacidmethylester2glm)

phexadecanoicacidmethylester2tuk <- glht(phexadecanoicacidmethylester2glm, linfct = mcp(treatment = "Tukey"))
summary(phexadecanoicacidmethylester2tuk)          # standard display
phexadecanoicacidmethylester2tuk.cld <- cld(phexadecanoicacidmethylester2tuk)   # letter-based display
phexadecanoicacidmethylester2tuk.cld
plot(phexadecanoicacidmethylester2tuk.cld, ylab="phexadecanoicacidmethylester2")

pmethyltricosane1glm<- glm(pmethyltricosane1~treatment, data=acppa)
summary(pmethyltricosane1glm)

pmethyltricosane1tuk <- glht(pmethyltricosane1glm, linfct = mcp(treatment = "Tukey"))
summary(pmethyltricosane1tuk)          # standard display
pmethyltricosane1tuk.cld <- cld(pmethyltricosane1tuk)   # letter-based display
pmethyltricosane1tuk.cld
plot(pmethyltricosane1tuk.cld, ylab="pmethyltricosane1")

pmethyltricosane2glm<- glm(pmethyltricosane2~treatment, data=acppa)
summary(pmethyltricosane2glm)

pmethyltricosane2tuk <- glht(pmethyltricosane2glm, linfct = mcp(treatment = "Tukey"))
summary(pmethyltricosane2tuk)          # standard display
pmethyltricosane2tuk.cld <- cld(pmethyltricosane2tuk)   # letter-based display
pmethyltricosane2tuk.cld
plot(pmethyltricosane2tuk.cld, ylab="pmethyltricosane2")
#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = pmethyltricosane2 ~ treatment, data = acppa)

#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0   0.02333    0.01841   1.267    0.413  
#Virus - Control == 0 -0.01571    0.01865  -0.842    0.676  
#Virus - Sham == 0    -0.03904    0.01740  -2.244    0.064 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)

#> pmethyltricosane2tuk.cld <- cld(pmethyltricosane2tuk)   # letter-based display
#> pmethyltricosane2tuk.cld
#Control    Sham   Virus 
#"a"     "a"     "a" 

pmethyltricosane2 <- summarySE(acppa, measurevar="pmethyltricosane2", groupvars=c("treatment"))
head(pmethyltricosane2)
pmethyltricosane2plot <- ggplot(pmethyltricosane2, aes(treatment, pmethyltricosane2, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=pmethyltricosane2-se, ymax=pmethyltricosane2+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
pmethyltricosane2plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - MethylTricosane 2") 

ggplot(acppa, aes(x=factor(treatment), y=pmethyltricosane2, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Methyl-Tricosane 2")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pmethylheptadecanoicacidglm<- glm(pmethylheptadecanoicacid~treatment, data=acppa)
summary(pmethylheptadecanoicacidglm)

pmethylheptadecanoicacidtuk <- glht(pmethylheptadecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylheptadecanoicacidtuk)          # standard display
pmethylheptadecanoicacidtuk.cld <- cld(pmethylheptadecanoicacidtuk)   # letter-based display
pmethylheptadecanoicacidtuk.cld
plot(pmethylheptadecanoicacidtuk.cld, ylab="pmethylheptadecanoicacid")

pndecanoicacidglm<- glm(pndecanoicacid~treatment, data=acppa)
summary(pndecanoicacidglm)

pndecanoicacidtuk <- glht(pndecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(pndecanoicacidtuk)          # standard display
pndecanoicacidtuk.cld <- cld(pndecanoicacidtuk)   # letter-based display
pndecanoicacidtuk.cld
plot(pndecanoicacidtuk.cld, ylab="pndecanoicacid")

pnonacosaneglm<- glm(pnonacosane~treatment, data=acppa)
summary(pnonacosaneglm)

pnonacosanetuk <- glht(pnonacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pnonacosanetuk)          # standard display
pnonacosanetuk.cld <- cld(pnonacosanetuk)   # letter-based display
pnonacosanetuk.cld
plot(pnonacosanetuk.cld, ylab="pnonacosane")

pnonadecaneglm<- glm(pnonadecane~treatment, data=acppa)
summary(pnonadecaneglm)

pnonadecanetuk <- glht(pnonadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(pnonadecanetuk)          # standard display
pnonadecanetuk.cld <- cld(pnonadecanetuk)   # letter-based display
pnonadecanetuk.cld
plot(pnonadecanetuk.cld, ylab="pnonadecane")

pnonadeceneglm<- glm(pnonadecene~treatment, data=acppa)
summary(pnonadeceneglm)

pnonadecenetuk <- glht(pnonadeceneglm, linfct = mcp(treatment = "Tukey"))
summary(pnonadecenetuk)          # standard display
pnonadecenetuk.cld <- cld(pnonadecenetuk)   # letter-based display
pnonadecenetuk.cld
plot(pnonadecenetuk.cld, ylab="pnonadecene")

punknownglm<- glm(punknown~treatment, data=acppa)
summary(punknownglm)

punknowntuk <- glht(punknownglm, linfct = mcp(treatment = "Tukey"))
summary(punknowntuk)          # standard display
punknowntuk.cld <- cld(punknowntuk)   # letter-based display
punknowntuk.cld
plot(punknowntuk.cld, ylab="punknown")
#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = punknown ~ treatment, data = acppa)

#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0   0.66571    0.31246   2.131   0.0837 .
#Virus - Control == 0 -0.04118    0.31667  -0.130   0.9907  
#Virus - Sham == 0    -0.70689    0.29540  -2.393   0.0440 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)

#> punknowntuk.cld <- cld(punknowntuk)   # letter-based display
#> punknowntuk.cld
#Control    Sham   Virus 
#"ab"     "b"     "a" 

punknown <- summarySE(acppa, measurevar="punknown", groupvars=c("treatment"))
head(punknown)
punknownplot <- ggplot(punknown, aes(treatment, punknown, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=punknown-se, ymax=punknown+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
punknownplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Unknown") 

ggplot(acppa, aes(x=factor(treatment), y=punknown, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Unknown")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pnonanoic.acidglm<- glm(pnonanoic.acid~treatment, data=acppa)
summary(pnonanoic.acidglm)

pnonanoic.acidtuk <- glht(pnonanoic.acidglm, linfct = mcp(treatment = "Tukey"))
summary(pnonanoic.acidtuk)          # standard display
pnonanoic.acidtuk.cld <- cld(pnonanoic.acidtuk)   # letter-based display
pnonanoic.acidtuk.cld
plot(pnonanoic.acidtuk.cld, ylab="pnonanoic.acid")

poctacoseneglm<- glm(poctacosene~treatment, data=acppa)
summary(poctacoseneglm)

poctacosenetuk <- glht(poctacoseneglm, linfct = mcp(treatment = "Tukey"))
summary(poctacosenetuk)          # standard display
poctacosenetuk.cld <- cld(poctacosenetuk)   # letter-based display
poctacosenetuk.cld
plot(poctacosenetuk.cld, ylab="poctacosene")

poctadecaneglm<- glm(poctadecane~treatment, data=acppa)
summary(poctadecaneglm)

poctadecanetuk <- glht(poctadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(poctadecanetuk)          # standard display
poctadecanetuk.cld <- cld(poctadecanetuk)   # letter-based display
poctadecanetuk.cld
plot(poctadecanetuk.cld, ylab="poctadecane")

poctacosaneglm<- glm(poctacosane~treatment, data=acppa)
summary(poctacosaneglm)

poctacosanetuk <- glht(poctacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(poctacosanetuk)          # standard display
poctacosanetuk.cld <- cld(poctacosanetuk)   # letter-based display
poctacosanetuk.cld
plot(poctacosanetuk.cld, ylab="poctacosane")
#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = poctacosane ~ treatment, data = acppa)

#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0    0.6630     0.4375   1.515   0.2834  
#Virus - Control == 0  -0.3226     0.4433  -0.728   0.7469  
#Virus - Sham == 0     -0.9856     0.4136  -2.383   0.0451 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> poctacosanetuk.cld <- cld(poctacosanetuk)   # letter-based display
#> poctacosanetuk.cld
#Control    Sham   Virus 
#"ab"     "b"     "a"

poctacosane <- summarySE(acppa, measurevar="poctacosane", groupvars=c("treatment"))
head(poctacosane)
poctacosaneplot <- ggplot(poctacosane, aes(treatment, poctacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=poctacosane-se, ymax=poctacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
poctacosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Octacosane") 

ggplot(acppa, aes(x=factor(treatment), y=poctacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Octacosane")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

poleicacid1glm<- glm(poleicacid1~treatment, data=acppa)
summary(poleicacid1glm)

poleicacid1tuk <- glht(poleicacid1glm, linfct = mcp(treatment = "Tukey"))
summary(poleicacid1tuk)          # standard display
poleicacid1tuk.cld <- cld(poleicacid1tuk)   # letter-based display
poleicacid1tuk.cld
plot(poleicacid1tuk.cld, ylab="poleicacid1")

poleicacid2glm<- glm(poleicacid2~treatment, data=acppa)
summary(poleicacid2glm)

poleicacid2tuk <- glht(poleicacid2glm, linfct = mcp(treatment = "Tukey"))
summary(poleicacid2tuk)          # standard display
poleicacid2tuk.cld <- cld(poleicacid2tuk)   # letter-based display
poleicacid2tuk.cld
plot(poleicacid2tuk.cld, ylab="poleicacid2")

poleicacid3glm<- glm(poleicacid3~treatment, data=acppa)
summary(poleicacid3glm)

poleicacid3tuk <- glht(poleicacid3glm, linfct = mcp(treatment = "Tukey"))
summary(poleicacid3tuk)          # standard display
poleicacid3tuk.cld <- cld(poleicacid3tuk)   # letter-based display
poleicacid3tuk.cld
plot(poleicacid3tuk.cld, ylab="poleicacid3")

pplasticizerglm<- glm(pplasticizer~treatment, data=acppa)
summary(pplasticizerglm)

pplasticizertuk <- glht(pplasticizerglm, linfct = mcp(treatment = "Tukey"))
summary(pplasticizertuk)          # standard display
pplasticizertuk.cld <- cld(pplasticizertuk)   # letter-based display
pplasticizertuk.cld
plot(pplasticizertuk.cld, ylab="pplasticizer")
#Plasticizer is pretty even - suggests contaminant??

ptetracosaneglm<- glm(ptetracosane~treatment, data=acppa)
summary(ptetracosaneglm)

ptetracosanetuk <- glht(ptetracosaneglm, linfct = mcp(treatment = "Tukey"))
summary(ptetracosanetuk)          # standard display
ptetracosanetuk.cld <- cld(ptetracosanetuk)   # letter-based display
ptetracosanetuk.cld
plot(ptetracosanetuk.cld, ylab="ptetracosane")

pthymolglm<- glm(pthymol~treatment, data=acppa)
summary(pthymolglm)

pthymoltuk <- glht(pthymolglm, linfct = mcp(treatment = "Tukey"))
summary(pthymoltuk)          # standard display
pthymoltuk.cld <- cld(pthymoltuk)   # letter-based display
pthymoltuk.cld
plot(pthymoltuk.cld, ylab="pthymol")

ptriacontane1glm<- glm(ptriacontane1~treatment, data=acppa)
summary(ptriacontane1glm)

ptriacontane1tuk <- glht(ptriacontane1glm, linfct = mcp(treatment = "Tukey"))
summary(ptriacontane1tuk)          # standard display
ptriacontane1tuk.cld <- cld(ptriacontane1tuk)   # letter-based display
ptriacontane1tuk.cld
plot(ptriacontane1tuk.cld, ylab="ptriacontane1")

ptriacontane2glm<- glm(ptriacontane2~treatment, data=acppa)
summary(ptriacontane2glm)

ptriacontane2tuk <- glht(ptriacontane2glm, linfct = mcp(treatment = "Tukey"))
summary(ptriacontane2tuk)          # standard display
ptriacontane2tuk.cld <- cld(ptriacontane2tuk)   # letter-based display
ptriacontane2tuk.cld
plot(ptriacontane2tuk.cld, ylab="ptriacontane2")

ptricosaneglm<- glm(ptricosane~treatment, data=acppa)
summary(ptricosaneglm)

ptricosanetuk <- glht(ptricosaneglm, linfct = mcp(treatment = "Tukey"))
summary(ptricosanetuk)          # standard display
ptricosanetuk.cld <- cld(ptricosanetuk)   # letter-based display
ptricosanetuk.cld
plot(ptricosanetuk.cld, ylab="ptricosane")

ptricosene1glm<- glm(ptricosene1~treatment, data=acppa)
summary(ptricosene1glm)

ptricosene1tuk <- glht(ptricosene1glm, linfct = mcp(treatment = "Tukey"))
summary(ptricosene1tuk)          # standard display
ptricosene1tuk.cld <- cld(ptricosene1tuk)   # letter-based display
ptricosene1tuk.cld
plot(ptricosene1tuk.cld, ylab="ptricosene1")

ptricosene2glm<- glm(ptricosene2~treatment, data=acppa)
summary(ptricosene2glm)

ptricosene2tuk <- glht(ptricosene2glm, linfct = mcp(treatment = "Tukey"))
summary(ptricosene2tuk)          # standard display
ptricosene2tuk.cld <- cld(ptricosene2tuk)   # letter-based display
ptricosene2tuk.cld
plot(ptricosene2tuk.cld, ylab="ptricosene2")

ptritriacontaneglm<- glm(ptritriacontane~treatment, data=acppa)
summary(ptritriacontaneglm)

ptritriacontanetuk <- glht(ptritriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(ptritriacontanetuk)          # standard display
ptritriacontanetuk.cld <- cld(ptritriacontanetuk)   # letter-based display
ptritriacontanetuk.cld
plot(ptritriacontanetuk.cld, ylab="ptritriacontane")

punknown1glm<- glm(punknown1~treatment, data=acppa)
summary(punknown1glm)

punknown1tuk <- glht(punknown1glm, linfct = mcp(treatment = "Tukey"))
summary(punknown1tuk)          # standard display
punknown1tuk.cld <- cld(punknown1tuk)   # letter-based display
punknown1tuk.cld
plot(punknown1tuk.cld, ylab="punknown1")

punknown1.5glm<- glm(punknown1.5~treatment, data=acppa)
summary(punknown1.5glm)

punknown1.5tuk <- glht(punknown1.5glm, linfct = mcp(treatment = "Tukey"))
summary(punknown1.5tuk)          # standard display
punknown1.5tuk.cld <- cld(punknown1.5tuk)   # letter-based display
punknown1.5tuk.cld
plot(punknown1.5tuk.cld, ylab="punknown1.5")

punknown2glm<- glm(punknown2~treatment, data=acppa)
summary(punknown2glm)

punknown2tuk <- glht(punknown2glm, linfct = mcp(treatment = "Tukey"))
summary(punknown2tuk)          # standard display
punknown2tuk.cld <- cld(punknown2tuk)   # letter-based display
punknown2tuk.cld
plot(punknown2tuk.cld, ylab="punknown2")
#Multiple Comparisons of Means: Tukey Contrasts
#Fit: glm(formula = punknown2 ~ treatment, data = acppa)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0   -6.4031     3.0343  -2.110   0.0877 .
#Virus - Control == 0  -6.0140     3.0751  -1.956   0.1232  
#Virus - Sham == 0      0.3891     2.8686   0.136   0.9899  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)

#> punknown2tuk.cld <- cld(punknown2tuk)   # letter-based display
#> punknown2tuk.cld
#Control    Sham   Virus 
#"a"     "a"     "a" 

punknown2 <- summarySE(acppa, measurevar="punknown2", groupvars=c("treatment"))
head(punknown2)
punknown2plot <- ggplot(punknown2, aes(treatment, punknown2, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=punknown2-se, ymax=punknown2+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
punknown2plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Unknown2") 

ggplot(acppa, aes(x=factor(treatment), y=punknown2, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Unknown 2")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

punknown3glm<- glm(punknown3~treatment, data=acppa)
summary(punknown3glm)

punknown3tuk <- glht(punknown3glm, linfct = mcp(treatment = "Tukey"))
summary(punknown3tuk)          # standard display
punknown3tuk.cld <- cld(punknown3tuk)   # letter-based display
punknown3tuk.cld
plot(punknown3tuk.cld, ylab="punknown3")

punknown3.5glm<- glm(punknown3.5~treatment, data=acppa)
summary(punknown3.5glm)

punknown3.5tuk <- glht(punknown3.5glm, linfct = mcp(treatment = "Tukey"))
summary(punknown3.5tuk)          # standard display
punknown3.5tuk.cld <- cld(punknown3.5tuk)   # letter-based display
punknown3.5tuk.cld
plot(punknown3.5tuk.cld, ylab="punknown3.5")

punknown4glm<- glm(punknown4~treatment, data=acppa)
summary(punknown4glm)

punknown4tuk <- glht(punknown4glm, linfct = mcp(treatment = "Tukey"))
summary(punknown4tuk)          # standard display
punknown4tuk.cld <- cld(punknown4tuk)   # letter-based display
punknown4tuk.cld
plot(punknown4tuk.cld, ylab="punknown4")
#Fit: glm(formula = punknown4 ~ treatment, data = acppa)

#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0   0.08826    0.10355   0.852   0.6702  
#Virus - Control == 0 -0.11979    0.10494  -1.142   0.4882  
#Virus - Sham == 0    -0.20805    0.09789  -2.125   0.0847 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)

#> punknown4tuk.cld <- cld(punknown4tuk)   # letter-based display
#> punknown4tuk.cld
#Control    Sham   Virus 
#"a"     "a"     "a" 

punknown4 <- summarySE(acppa, measurevar="punknown4", groupvars=c("treatment"))
head(punknown4)
punknown4plot <- ggplot(punknown4, aes(treatment, punknown4, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=punknown4-se, ymax=punknown4+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
punknown4plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "PPA - Unknown4") 

ggplot(acppa, aes(x=factor(treatment), y=punknown4, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Unknown 4")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################
####################################


# acng = all compounds, ng of each
acng <- read.csv("2017_AllCompounds_ng.csv", header=T, sep = ";");

#Convert column names to lower case
colnames(acng) <- tolower(colnames(acng))
colnames(acng)
View(acng)

# Rename "dsRNA" to "sham" for clarity
levels(acng$treatment)[levels(acng$treatment)=="Virus"] <- "IAPV"

##################################################################


# Comparisons - Nanogram of compound
hentriaconteneglm<- glm(hentriacontene~treatment, data=acng)
summary(hentriaconteneglm)
hentriacontenetuk <- glht(hentriaconteneglm, linfct = mcp(treatment = "Tukey"))
summary(hentriacontenetuk)          # standard display
hentriacontenetuk.cld <- cld(hentriacontenetuk)   # letter-based display
hentriacontenetuk.cld
plot(hentriacontenetuk.cld, ylab="hentriacontene")

methylhentriacontaneglm<- glm(methylhentriacontane~treatment, data=acng)
summary(methylhentriacontaneglm)
methylhentriacontanetuk <- glht(methylhentriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(methylhentriacontanetuk)          # standard display
methylhentriacontanetuk.cld <- cld(methylhentriacontanetuk)   # letter-based display
methylhentriacontanetuk.cld
plot(methylhentriacontanetuk.cld, ylab="methylhentriacontane")

methylheptacosaneglm<- glm(methylheptacosane~treatment, data=acng)
summary(methylheptacosaneglm)
methylheptacosanetuk <- glht(methylheptacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(methylheptacosanetuk)          # standard display
methylheptacosanetuk.cld <- cld(methylheptacosanetuk)   # letter-based display
methylheptacosanetuk.cld
plot(methylheptacosanetuk.cld, ylab="methylheptacosane")

methylnonacosaneglm<- glm(methylnonacosane~treatment, data=acng)
summary(methylnonacosaneglm)
methylnonacosanetuk <- glht(methylnonacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(methylnonacosanetuk)          # standard display
methylnonacosanetuk.cld <- cld(methylnonacosanetuk)   # letter-based display
methylnonacosanetuk.cld
plot(methylnonacosanetuk.cld, ylab="methylnonacosane")
#> methylnonacosaneglm<- glm(methylnonacosane~treatment, data=acng)
#> summary(methylnonacosaneglm)
#
#Call:
#  glm(formula = methylnonacosane ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-196.39  -100.90   -27.08    94.74   624.47  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)  
#(Intercept)      100.90      48.58   2.077   0.0438 *
#  treatmentdsRNA    95.49      64.53   1.480   0.1462  
#treatmentVirus   -73.82      65.40  -1.129   0.2652  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 30673.98)
#
#Null deviance: 1556935  on 45  degrees of freedom
#Residual deviance: 1318981  on 43  degrees of freedom
#AIC: 610.67
#
#Number of Fisher Scoring iterations: 2
#
#> methylnonacosanetuk <- glht(methylnonacosaneglm, linfct = mcp(treatment = "Tukey"))
#> summary(methylnonacosanetuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = methylnonacosane ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0    95.49      64.53   1.480   0.3004  
#Virus - Control == 0   -73.82      65.40  -1.129   0.4960  
#Virus - dsRNA == 0    -169.31      61.00  -2.775   0.0153 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> methylnonacosanetuk.cld <- cld(methylnonacosanetuk)   # letter-based display
#> methylnonacosanetuk.cld
#Control   dsRNA   Virus 
#"ab"     "b"     "a" 
methylnonacosane <- summarySE(acng, measurevar="methylnonacosane", groupvars=c("treatment"))
head(methylnonacosane)
methylnonacosaneplot <- ggplot(methylnonacosane, aes(treatment, methylnonacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=methylnonacosane-se, ymax=methylnonacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
methylnonacosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Methyl Nonacosane") 

ggplot(acng, aes(x=factor(treatment), y=methylnonacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Methyl-Nonacosane (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

methyltriacontaneglm<- glm(methyltriacontane~treatment, data=acng)
summary(methyltriacontaneglm)
methyltriacontanetuk <- glht(methyltriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(methyltriacontanetuk)          # standard display
methyltriacontanetuk.cld <- cld(methyltriacontanetuk)   # letter-based display
methyltriacontanetuk.cld
plot(methyltriacontanetuk.cld, ylab="methyltriacontane")

dcarvoneglm<- glm(dcarvone~treatment, data=acng)
summary(dcarvoneglm)
dcarvonetuk <- glht(dcarvoneglm, linfct = mcp(treatment = "Tukey"))
summary(dcarvonetuk)          # standard display
dcarvonetuk.cld <- cld(dcarvonetuk)   # letter-based display
dcarvonetuk.cld
plot(dcarvonetuk.cld, ylab="dcarvone")

dlimoneneglm<- glm(dlimonene~treatment, data=acng)
summary(dlimoneneglm)
dlimonenetuk <- glht(dlimoneneglm, linfct = mcp(treatment = "Tukey"))
summary(dlimonenetuk)          # standard display
dlimonenetuk.cld <- cld(dlimonenetuk)   # letter-based display
dlimonenetuk.cld
plot(dlimonenetuk.cld, ylab="dlimonene")

decanalglm<- glm(decanal~treatment, data=acng)
summary(decanalglm)
decanaltuk <- glht(decanalglm, linfct = mcp(treatment = "Tukey"))
summary(decanaltuk)          # standard display
decanaltuk.cld <- cld(decanaltuk)   # letter-based display
decanaltuk.cld
plot(decanaltuk.cld, ylab="decanal")
#> decanalglm<- glm(decanal~treatment, data=acng)
#> summary(decanalglm)
#
#Call:
#  glm(formula = decanal ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-27.014  -20.811   -2.961   15.008   55.596  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)   
#  (Intercept)       2.961      5.854   0.506  0.61562   
#  treatmentdsRNA   18.161      7.777   2.335  0.02426 * 
#  treatmentVirus   24.053      7.881   3.052  0.00389 **
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 445.5097)
#
#Null deviance: 23563  on 45  degrees of freedom
#Residual deviance: 19157  on 43  degrees of freedom
#AIC: 416
#
#Number of Fisher Scoring iterations: 2
#
#> decanaltuk <- glht(decanalglm, linfct = mcp(treatment = "Tukey"))
#> summary(decanaltuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = decanal ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)   
#  dsRNA - Control == 0   18.161      7.777   2.335   0.0510 . 
#  Virus - Control == 0   24.053      7.881   3.052   0.0064 **
#  Virus - dsRNA == 0      5.892      7.352   0.801   0.7019   
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> decanaltuk.cld <- cld(decanaltuk)   # letter-based display
#> decanaltuk.cld
#Control   dsRNA   Virus 
#"a"    "ab"     "b" 
decanal <- summarySE(acng, measurevar="decanal", groupvars=c("treatment"))
head(decanal)
decanalplot <- ggplot(decanal, aes(treatment, decanal, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=decanal-se, ymax=decanal+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
decanalplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Decanal") 

ggplot(acng, aes(x=factor(treatment), y=decanal, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Decanal (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

docosaneglm<- glm(docosane~treatment, data=acng)
summary(docosaneglm)
docosanetuk <- glht(docosaneglm, linfct = mcp(treatment = "Tukey"))
summary(docosanetuk)          # standard display
docosanetuk.cld <- cld(docosanetuk)   # letter-based display
docosanetuk.cld
plot(docosanetuk.cld, ylab="docosane")

eicosaneglm<- glm(eicosane~treatment, data=acng)
summary(eicosaneglm)
eicosanetuk <- glht(eicosaneglm, linfct = mcp(treatment = "Tukey"))
summary(eicosanetuk)          # standard display
eicosanetuk.cld <- cld(eicosanetuk)   # letter-based display
eicosanetuk.cld
plot(eicosanetuk.cld, ylab="eicosane")

heneicosane1glm<- glm(heneicosane1~treatment, data=acng)
summary(heneicosane1glm)
heneicosane1tuk <- glht(heneicosane1glm, linfct = mcp(treatment = "Tukey"))
summary(heneicosane1tuk)          # standard display
heneicosane1tuk.cld <- cld(heneicosane1tuk)   # letter-based display
heneicosane1tuk.cld
plot(heneicosane1tuk.cld, ylab="heneicosane1")

heneicosane2glm<- glm(heneicosane2~treatment, data=acng)
summary(heneicosane2glm)
heneicosane2tuk <- glht(heneicosane2glm, linfct = mcp(treatment = "Tukey"))
summary(heneicosane2tuk)          # standard display
heneicosane2tuk.cld <- cld(heneicosane2tuk)   # letter-based display
heneicosane2tuk.cld
plot(heneicosane2tuk.cld, ylab="heneicosane2")

heneicoseneglm<- glm(heneicosene~treatment, data=acng)
summary(heneicoseneglm)
heneicosenetuk <- glht(heneicoseneglm, linfct = mcp(treatment = "Tukey"))
summary(heneicosenetuk)          # standard display
heneicosenetuk.cld <- cld(heneicosenetuk)   # letter-based display
heneicosenetuk.cld
plot(heneicosenetuk.cld, ylab="heneicosene")
#> heneicoseneglm<- glm(heneicosene~treatment, data=acng)
#> summary(heneicoseneglm)
#
#Call:
#  glm(formula = heneicosene ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-46.404  -24.597   -1.007   20.086   57.623  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)    
#  (Intercept)      32.634      7.927   4.117 0.000171 ***
#  treatmentdsRNA   13.770     10.530   1.308 0.197939    
#  treatmentVirus   -8.037     10.672  -0.753 0.455512    
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 816.895)
#
#Null deviance: 39141  on 45  degrees of freedom
#Residual deviance: 35126  on 43  degrees of freedom
#AIC: 443.89
#
#Number of Fisher Scoring iterations: 2
#
#> heneicosenetuk <- glht(heneicoseneglm, linfct = mcp(treatment = "Tukey"))
#> summary(heneicosenetuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = heneicosene ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0   13.770     10.530   1.308   0.3906  
#Virus - Control == 0   -8.037     10.672  -0.753   0.7316  
#Virus - dsRNA == 0    -21.807      9.955  -2.190   0.0727 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> heneicosenetuk.cld <- cld(heneicosenetuk)   # letter-based display
#> heneicosenetuk.cld
#Control   dsRNA   Virus 
#"a"     "a"     "a" 
heneicosene <- summarySE(acng, measurevar="heneicosene", groupvars=c("treatment"))
head(heneicosene)
heneicoseneplot <- ggplot(heneicosene, aes(treatment, heneicosene, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=heneicosene-se, ymax=heneicosene+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
heneicoseneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Heneicosene") 

ggplot(acng, aes(x=factor(treatment), y=heneicosene, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Heneicosene (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

hentriacontaneglm<- glm(hentriacontane~treatment, data=acng)
summary(hentriacontaneglm)
hentriacontanetuk <- glht(hentriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(hentriacontanetuk)          # standard display
hentriacontanetuk.cld <- cld(hentriacontanetuk)   # letter-based display
hentriacontanetuk.cld
plot(hentriacontanetuk.cld, ylab="hentriacontane")

heptacosaneglm<- glm(heptacosane~treatment, data=acng)
summary(heptacosaneglm)
heptacosanetuk <- glht(heptacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(heptacosanetuk)          # standard display
heptacosanetuk.cld <- cld(heptacosanetuk)   # letter-based display
heptacosanetuk.cld
plot(heptacosanetuk.cld, ylab="heptacosane")
#> heptacosaneglm<- glm(heptacosane~treatment, data=acng)
#> summary(heptacosaneglm)
#
#Call:
#  glm(formula = heptacosane ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-3080.9  -1452.7   -169.5    796.4   6650.0  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)    
#(Intercept)      3080.9      526.8   5.848 6.08e-07 ***
#  treatmentdsRNA  -1022.2      699.9  -1.461   0.1514    
#treatmentVirus  -1628.2      709.3  -2.296   0.0266 *  
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 3608330)
#
#Null deviance: 174336585  on 45  degrees of freedom
#Residual deviance: 155158194  on 43  degrees of freedom
#AIC: 829.98
#
#Number of Fisher Scoring iterations: 2
#
#> heptacosanetuk <- glht(heptacosaneglm, linfct = mcp(treatment = "Tukey"))
#> summary(heptacosanetuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = heptacosane ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0  -1022.2      699.9  -1.461   0.3099  
#Virus - Control == 0  -1628.2      709.3  -2.296   0.0563 .
#Virus - dsRNA == 0     -606.0      661.6  -0.916   0.6300  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> heptacosanetuk.cld <- cld(heptacosanetuk)   # letter-based display
#> heptacosanetuk.cld
#Control   dsRNA   Virus 
#"a"     "a"     "a" 
heptacosane <- summarySE(acng, measurevar="heptacosane", groupvars=c("treatment"))
head(heptacosane)
heptacosaneplot <- ggplot(heptacosane, aes(treatment, heptacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=heptacosane-se, ymax=heptacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
heptacosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Heptacosane") 

ggplot(acng, aes(x=factor(treatment), y=heptacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Heptacosane (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)


heptadecaneglm<- glm(heptadecane~treatment, data=acng)
summary(heptadecaneglm)
heptadecanetuk <- glht(heptadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(heptadecanetuk)          # standard display
heptadecanetuk.cld <- cld(heptadecanetuk)   # letter-based display
heptadecanetuk.cld
plot(heptadecanetuk.cld, ylab="heptadecane")

hexacosaneglm<- glm(hexacosane~treatment, data=acng)
summary(hexacosaneglm)
hexacosanetuk <- glht(hexacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(hexacosanetuk)          # standard display
hexacosanetuk.cld <- cld(hexacosanetuk)   # letter-based display
hexacosanetuk.cld
plot(hexacosanetuk.cld, ylab="hexacosane")

hexadecaneglm<- glm(hexadecane~treatment, data=acng)
summary(hexadecaneglm)
hexadecanetuk <- glht(hexadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(hexadecanetuk)          # standard display
hexadecanetuk.cld <- cld(hexadecanetuk)   # letter-based display
hexadecanetuk.cld
plot(hexadecanetuk.cld, ylab="hexadecane")

hexadecenoicacidglm<- glm(hexadecenoicacid~treatment, data=acng)
summary(hexadecenoicacidglm)
hexadecenoicacidtuk <- glht(hexadecenoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(hexadecenoicacidtuk)          # standard display
hexadecenoicacidtuk.cld <- cld(hexadecenoicacidtuk)   # letter-based display
hexadecenoicacidtuk.cld
plot(hexadecenoicacidtuk.cld, ylab="hexadecenoicacid")

hexadecanoicacidglm<- glm(hexadecanoicacid~treatment, data=acng)
summary(hexadecanoicacidglm)
hexadecanoicacidtuk <- glht(hexadecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(hexadecanoicacidtuk)          # standard display
hexadecanoicacidtuk.cld <- cld(hexadecanoicacidtuk)   # letter-based display
hexadecanoicacidtuk.cld
plot(hexadecanoicacidtuk.cld, ylab="hexadecanoicacid")

hexadecanoicacidmethylester1glm<- glm(hexadecanoicacidmethylester1~treatment, data=acng)
summary(hexadecanoicacidmethylester1glm)
hexadecanoicacidmethylester1tuk <- glht(hexadecanoicacidmethylester1glm, linfct = mcp(treatment = "Tukey"))
summary(hexadecanoicacidmethylester1tuk)          # standard display
hexadecanoicacidmethylester1tuk.cld <- cld(hexadecanoicacidmethylester1tuk)   # letter-based display
hexadecanoicacidmethylester1tuk.cld
plot(hexadecanoicacidmethylester1tuk.cld, ylab="hexadecanoicacidmethylester1")

hexadecanoicacidmethylester2glm<- glm(hexadecanoicacidmethylester2~treatment, data=acng)
summary(hexadecanoicacidmethylester2glm)
hexadecanoicacidmethylester2tuk <- glht(hexadecanoicacidmethylester2glm, linfct = mcp(treatment = "Tukey"))
summary(hexadecanoicacidmethylester2tuk)          # standard display
hexadecanoicacidmethylester2tuk.cld <- cld(hexadecanoicacidmethylester2tuk)   # letter-based display
hexadecanoicacidmethylester2tuk.cld
plot(hexadecanoicacidmethylester2tuk.cld, ylab="hexadecanoicacidmethylester2")

methyltricosane1glm<- glm(methyltricosane1~treatment, data=acng)
summary(methyltricosane1glm)
methyltricosane1tuk <- glht(methyltricosane1glm, linfct = mcp(treatment = "Tukey"))
summary(methyltricosane1tuk)          # standard display
methyltricosane1tuk.cld <- cld(methyltricosane1tuk)   # letter-based display
methyltricosane1tuk.cld
plot(methyltricosane1tuk.cld, ylab="methyltricosane1")
#> methyltricosane1glm<- glm(methyltricosane1~treatment, data=acng)
#> summary(methyltricosane1glm)
#
#Call:
#  glm(formula = methyltricosane1 ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min      1Q  Median      3Q     Max  
#-13.91  -11.74   -2.43   11.07   35.53  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)  
#   (Intercept)       2.430      3.799   0.640   0.5259  
#   treatmentdsRNA   11.484      5.047   2.276   0.0279 *
#  treatmentVirus    9.308      5.115   1.820   0.0757 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 187.6287)
#
#Null deviance: 9121.4  on 45  degrees of freedom
#Residual deviance: 8068.0  on 43  degrees of freedom
#AIC: 376.23
#
#Number of Fisher Scoring iterations: 2
#
#> methyltricosane1tuk <- glht(methyltricosane1glm, linfct = mcp(treatment = "Tukey"))
#> summary(methyltricosane1tuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = methyltricosane1 ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0   11.484      5.047   2.276   0.0592 .
#Virus - Control == 0    9.308      5.115   1.820   0.1629  
#Virus - dsRNA == 0     -2.176      4.771  -0.456   0.8916  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> methyltricosane1tuk.cld <- cld(methyltricosane1tuk)   # letter-based display
#> methyltricosane1tuk.cld
#Control   dsRNA   Virus 
#"a"     "a"     "a" 
methyltricosane1 <- summarySE(acng, measurevar="methyltricosane1", groupvars=c("treatment"))
head(methyltricosane1)
methyltricosane1plot <- ggplot(methyltricosane1, aes(treatment, methyltricosane1, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=methyltricosane1-se, ymax=methyltricosane1+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
methyltricosane1plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Methyl Tricosane1") 

ggplot(acng, aes(x=factor(treatment), y=methyltricosane1, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Methyl-Tricosane 1 (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

methyltricosane2glm<- glm(methyltricosane2~treatment, data=acng)
summary(methyltricosane2glm)
methyltricosane2tuk <- glht(methyltricosane2glm, linfct = mcp(treatment = "Tukey"))
summary(methyltricosane2tuk)          # standard display
methyltricosane2tuk.cld <- cld(methyltricosane2tuk)   # letter-based display
methyltricosane2tuk.cld
plot(methyltricosane2tuk.cld, ylab="methyltricosane2")
#> methyltricosane2glm<- glm(methyltricosane2~treatment, data=acng)
#> summary(methyltricosane2glm)
#
#Call:
#  glm(formula = methyltricosane2 ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-5.9045  -4.6514  -0.8922   0.0000  22.5005  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)  
#  (Intercept)      0.8922     1.7227   0.518    0.607  
#  treatmentdsRNA   5.0124     2.2885   2.190    0.034 *
#  treatmentVirus  -0.8922     2.3193  -0.385    0.702  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 38.58143)
#
#Null deviance: 1989.5  on 45  degrees of freedom
#Residual deviance: 1659.0  on 43  degrees of freedom
#AIC: 303.47
#
#Number of Fisher Scoring iterations: 2
#
#> methyltricosane2tuk <- glht(methyltricosane2glm, linfct = mcp(treatment = "Tukey"))
#> summary(methyltricosane2tuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = methyltricosane2 ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0   5.0124     2.2885   2.190   0.0727 .
#Virus - Control == 0  -0.8922     2.3193  -0.385   0.9216  
#Virus - dsRNA == 0    -5.9045     2.1635  -2.729   0.0173 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> methyltricosane2tuk.cld <- cld(methyltricosane2tuk)   # letter-based display
#> methyltricosane2tuk.cld
#Control   dsRNA   Virus 
#"ab"     "b"     "a" 
methyltricosane2 <- summarySE(acng, measurevar="methyltricosane2", groupvars=c("treatment"))
head(methyltricosane2)
methyltricosane2plot <- ggplot(methyltricosane2, aes(treatment, methyltricosane2, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=methyltricosane2-se, ymax=methyltricosane2+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
methyltricosane2plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Methyl Tricosane2") 

ggplot(acng, aes(x=factor(treatment), y=methyltricosane2, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Methyl-Tricosane 2 (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

methylheptadecanoicacidglm<- glm(methylheptadecanoicacid~treatment, data=acng)
summary(methylheptadecanoicacidglm)
methylheptadecanoicacidtuk <- glht(methylheptadecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(methylheptadecanoicacidtuk)          # standard display
methylheptadecanoicacidtuk.cld <- cld(methylheptadecanoicacidtuk)   # letter-based display
methylheptadecanoicacidtuk.cld
plot(methylheptadecanoicacidtuk.cld, ylab="methylheptadecanoicacid")

ndecanoicacidglm<- glm(ndecanoicacid~treatment, data=acng)
summary(ndecanoicacidglm)
ndecanoicacidtuk <- glht(ndecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(ndecanoicacidtuk)          # standard display
ndecanoicacidtuk.cld <- cld(ndecanoicacidtuk)   # letter-based display
ndecanoicacidtuk.cld
plot(ndecanoicacidtuk.cld, ylab="ndecanoicacid")
#ndecanoicacidglm<- glm(ndecanoicacid~treatment, data=acng)
#> summary(ndecanoicacidglm)
#
#Call:
#  glm(formula = ndecanoicacid ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-24.843  -15.007    0.000    9.211   49.034  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)   
#(Intercept)    -1.362e-14  5.362e+00   0.000   1.0000   
#treatmentdsRNA  1.501e+01  7.123e+00   2.107   0.0410 * 
#  treatmentVirus  2.484e+01  7.219e+00   3.441   0.0013 **
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 373.76)
#
#Null deviance: 20516  on 45  degrees of freedom
#Residual deviance: 16072  on 43  degrees of freedom
#AIC: 407.93
#
#Number of Fisher Scoring iterations: 2
#
#> ndecanoicacidtuk <- glht(ndecanoicacidglm, linfct = mcp(treatment = "Tukey"))
#> summary(ndecanoicacidtuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = ndecanoicacid ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)   
#dsRNA - Control == 0   15.007      7.123   2.107  0.08832 . 
#Virus - Control == 0   24.843      7.219   3.441  0.00167 **
#  Virus - dsRNA == 0      9.836      6.734   1.461  0.30982   
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> ndecanoicacidtuk.cld <- cld(ndecanoicacidtuk)   # letter-based display
#> ndecanoicacidtuk.cld
#Control   dsRNA   Virus 
#"a"    "ab"     "b" 
ndecanoicacid <- summarySE(acng, measurevar="ndecanoicacid", groupvars=c("treatment"))
head(ndecanoicacid)
ndecanoicacidplot <- ggplot(ndecanoicacid, aes(treatment, ndecanoicacid, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=ndecanoicacid-se, ymax=ndecanoicacid+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
ndecanoicacidplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - nDecanoid Acid") 

ggplot(acng, aes(x=factor(treatment), y=ndecanoicacid, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("n-Decanoic Acid (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

nonacosaneglm<- glm(nonacosane~treatment, data=acng)
summary(nonacosaneglm)
nonacosanetuk <- glht(nonacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(nonacosanetuk)          # standard display
nonacosanetuk.cld <- cld(nonacosanetuk)   # letter-based display
nonacosanetuk.cld
plot(nonacosanetuk.cld, ylab="nonacosane")

nonadecaneglm<- glm(nonadecane~treatment, data=acng)
summary(nonadecaneglm)
nonadecanetuk <- glht(nonadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(nonadecanetuk)          # standard display
nonadecanetuk.cld <- cld(nonadecanetuk)   # letter-based display
nonadecanetuk.cld
plot(nonadecanetuk.cld, ylab="nonadecane")

nonadeceneglm<- glm(nonadecene~treatment, data=acng)
summary(nonadeceneglm)
nonadecenetuk <- glht(nonadeceneglm, linfct = mcp(treatment = "Tukey"))
summary(nonadecenetuk)          # standard display
nonadecenetuk.cld <- cld(nonadecenetuk)   # letter-based display
nonadecenetuk.cld
plot(nonadecenetuk.cld, ylab="nonadecene")

unknownglm<- glm(unknown~treatment, data=acng)
summary(unknownglm)
unknowntuk <- glht(unknownglm, linfct = mcp(treatment = "Tukey"))
summary(unknowntuk)          # standard display
unknowntuk.cld <- cld(unknowntuk)   # letter-based display
unknowntuk.cld
plot(unknowntuk.cld, ylab="unknown")

nonanoicacidglm<- glm(nonanoicacid~treatment, data=acng)
summary(nonanoicacidglm)
nonanoicacidtuk <- glht(nonanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(nonanoicacidtuk)          # standard display
nonanoicacidtuk.cld <- cld(nonanoicacidtuk)   # letter-based display
nonanoicacidtuk.cld
plot(nonanoicacidtuk.cld, ylab="nonanoicacid")

octacoseneglm<- glm(octacosene~treatment, data=acng)
summary(octacoseneglm)
octacosenetuk <- glht(octacoseneglm, linfct = mcp(treatment = "Tukey"))
summary(octacosenetuk)          # standard display
octacosenetuk.cld <- cld(octacosenetuk)   # letter-based display
octacosenetuk.cld
plot(octacosenetuk.cld, ylab="octacosene")

octadecaneglm<- glm(octadecane~treatment, data=acng)
summary(octadecaneglm)
octadecanetuk <- glht(octadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(octadecanetuk)          # standard display
octadecanetuk.cld <- cld(octadecanetuk)   # letter-based display
octadecanetuk.cld
plot(octadecanetuk.cld, ylab="octadecane")

octacosaneglm<- glm(octacosane~treatment, data=acng)
summary(octacosaneglm)
octacosanetuk <- glht(octacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(octacosanetuk)          # standard display
octacosanetuk.cld <- cld(octacosanetuk)   # letter-based display
octacosanetuk.cld
plot(octacosanetuk.cld, ylab="octacosane")

oleicacid1glm<- glm(oleicacid1~treatment, data=acng)
summary(oleicacid1glm)
oleicacid1tuk <- glht(oleicacid1glm, linfct = mcp(treatment = "Tukey"))
summary(oleicacid1tuk)          # standard display
oleicacid1tuk.cld <- cld(oleicacid1tuk)   # letter-based display
oleicacid1tuk.cld
plot(oleicacid1tuk.cld, ylab="oleicacid1")

oleicacid2glm<- glm(oleicacid2~treatment, data=acng)
summary(oleicacid2glm)
oleicacid2tuk <- glht(oleicacid2glm, linfct = mcp(treatment = "Tukey"))
summary(oleicacid2tuk)          # standard display
oleicacid2tuk.cld <- cld(oleicacid2tuk)   # letter-based display
oleicacid2tuk.cld
plot(oleicacid2tuk.cld, ylab="oleicacid2")

oleicacid3glm<- glm(oleicacid3~treatment, data=acng)
summary(oleicacid3glm)
oleicacid3tuk <- glht(oleicacid3glm, linfct = mcp(treatment = "Tukey"))
summary(oleicacid3tuk)          # standard display
oleicacid3tuk.cld <- cld(oleicacid3tuk)   # letter-based display
oleicacid3tuk.cld
plot(oleicacid3tuk.cld, ylab="oleicacid3")

plasticizerglm<- glm(plasticizer~treatment, data=acng)
summary(plasticizerglm)
plasticizertuk <- glht(plasticizerglm, linfct = mcp(treatment = "Tukey"))
summary(plasticizertuk)          # standard display
plasticizertuk.cld <- cld(plasticizertuk)   # letter-based display
plasticizertuk.cld
plot(plasticizertuk.cld, ylab="plasticizer")

tetracosaneglm<- glm(tetracosane~treatment, data=acng)
summary(tetracosaneglm)
tetracosanetuk <- glht(tetracosaneglm, linfct = mcp(treatment = "Tukey"))
summary(tetracosanetuk)          # standard display
tetracosanetuk.cld <- cld(tetracosanetuk)   # letter-based display
tetracosanetuk.cld
plot(tetracosanetuk.cld, ylab="tetracosane")

thymolglm<- glm(thymol~treatment, data=acng)
summary(thymolglm)
thymoltuk <- glht(thymolglm, linfct = mcp(treatment = "Tukey"))
summary(thymoltuk)          # standard display
thymoltuk.cld <- cld(thymoltuk)   # letter-based display
thymoltuk.cld
plot(thymoltuk.cld, ylab="thymol")

triacontane1glm<- glm(triacontane1~treatment, data=acng)
summary(triacontane1glm)
triacontane1tuk <- glht(triacontane1glm, linfct = mcp(treatment = "Tukey"))
summary(triacontane1tuk)          # standard display
triacontane1tuk.cld <- cld(triacontane1tuk)   # letter-based display
triacontane1tuk.cld
plot(triacontane1tuk.cld, ylab="triacontane1")

triacontane2glm<- glm(triacontane2~treatment, data=acng)
summary(triacontane2glm)
triacontane2tuk <- glht(triacontane2glm, linfct = mcp(treatment = "Tukey"))
summary(triacontane2tuk)          # standard display
triacontane2tuk.cld <- cld(triacontane2tuk)   # letter-based display
triacontane2tuk.cld
plot(triacontane2tuk.cld, ylab="triacontane2")

tricosaneglm<- glm(tricosane~treatment, data=acng)
summary(tricosaneglm)
tricosanetuk <- glht(tricosaneglm, linfct = mcp(treatment = "Tukey"))
summary(tricosanetuk)          # standard display
tricosanetuk.cld <- cld(tricosanetuk)   # letter-based display
tricosanetuk.cld
plot(tricosanetuk.cld, ylab="tricosane")

tricosene1glm<- glm(tricosene1~treatment, data=acng)
summary(tricosene1glm)
tricosene1tuk <- glht(tricosene1glm, linfct = mcp(treatment = "Tukey"))
summary(tricosene1tuk)          # standard display
tricosene1tuk.cld <- cld(tricosene1tuk)   # letter-based display
tricosene1tuk.cld
plot(tricosene1tuk.cld, ylab="tricosene1")

tricosene2glm<- glm(tricosene2~treatment, data=acng)
summary(tricosene2glm)
tricosene2tuk <- glht(tricosene2glm, linfct = mcp(treatment = "Tukey"))
summary(tricosene2tuk)          # standard display
tricosene2tuk.cld <- cld(tricosene2tuk)   # letter-based display
tricosene2tuk.cld
plot(tricosene2tuk.cld, ylab="tricosene2")

tritriacontaneglm<- glm(tritriacontane~treatment, data=acng)
summary(tritriacontaneglm)
tritriacontanetuk <- glht(tritriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(tritriacontanetuk)          # standard display
tritriacontanetuk.cld <- cld(tritriacontanetuk)   # letter-based display
tritriacontanetuk.cld
plot(tritriacontanetuk.cld, ylab="tritriacontane")

unknown1glm<- glm(unknown1~treatment, data=acng)
summary(unknown1glm)
unknown1tuk <- glht(unknown1glm, linfct = mcp(treatment = "Tukey"))
summary(unknown1tuk)          # standard display
unknown1tuk.cld <- cld(unknown1tuk)   # letter-based display
unknown1tuk.cld
plot(unknown1tuk.cld, ylab="unknown1")

unknown1.5glm<- glm(unknown1.5~treatment, data=acng)
summary(unknown1.5glm)
unknown1.5tuk <- glht(unknown1.5glm, linfct = mcp(treatment = "Tukey"))
summary(unknown1.5tuk)          # standard display
unknown1.5tuk.cld <- cld(unknown1.5tuk)   # letter-based display
unknown1.5tuk.cld
plot(unknown1.5tuk.cld, ylab="unknown1.5")

unknown2glm<- glm(unknown2~treatment, data=acng)
summary(unknown2glm)
unknown2tuk <- glht(unknown2glm, linfct = mcp(treatment = "Tukey"))
summary(unknown2tuk)          # standard display
unknown2tuk.cld <- cld(unknown2tuk)   # letter-based display
unknown2tuk.cld
plot(unknown2tuk.cld, ylab="unknown2")
#> unknown2glm<- glm(unknown2~treatment, data=acng)
#> summary(unknown2glm)
#
#Call:
#  glm(formula = unknown2 ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-1619.1  -1007.0   -618.7    742.7   2987.6  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)    
#(Intercept)      1766.6      367.0   4.814 1.86e-05 ***
#  treatmentdsRNA   -708.5      487.5  -1.453   0.1534    
#treatmentVirus  -1014.0      494.0  -2.052   0.0463 *  
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 1750568)
#
#Null deviance: 82886504  on 45  degrees of freedom
#Residual deviance: 75274423  on 43  degrees of freedom
#AIC: 796.71
#
#Number of Fisher Scoring iterations: 2
#
#> unknown2tuk <- glht(unknown2glm, linfct = mcp(treatment = "Tukey"))
#> summary(unknown2tuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = unknown2 ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0   -708.5      487.5  -1.453   0.3134  
#Virus - Control == 0  -1014.0      494.0  -2.052   0.0998 .
#Virus - dsRNA == 0     -305.5      460.9  -0.663   0.7849  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> unknown2tuk.cld <- cld(unknown2tuk)   # letter-based display
#> unknown2tuk.cld
#Control   dsRNA   Virus 
#"a"     "a"     "a" 
unknown2 <- summarySE(acng, measurevar="unknown2", groupvars=c("treatment"))
head(unknown2)
unknown2plot <- ggplot(unknown2, aes(treatment, unknown2, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=unknown2-se, ymax=unknown2+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
unknown2plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Unknown") 

ggplot(acng, aes(x=factor(treatment), y=unknown2, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Unknown 2 (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

unknown3glm<- glm(unknown3~treatment, data=acng)
summary(unknown3glm)
unknown3tuk <- glht(unknown3glm, linfct = mcp(treatment = "Tukey"))
summary(unknown3tuk)          # standard display
unknown3tuk.cld <- cld(unknown3tuk)   # letter-based display
unknown3tuk.cld
plot(unknown3tuk.cld, ylab="unknown3")
#> unknown3glm<- glm(unknown3~treatment, data=acng)
#> summary(unknown3glm)
#
#Call:
# glm(formula = unknown3 ~ treatment, data = acng)
##
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-13.773   -4.400   -3.180    6.025   32.165  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)  
#(Intercept)       3.180      3.441   0.924   0.3606  
#treatmentdsRNA   10.593      4.571   2.318   0.0253 *
#  treatmentVirus    1.221      4.632   0.264   0.7934  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 153.899)
#
#Null deviance: 7683.0  on 45  degrees of freedom
#Residual deviance: 6617.7  on 43  degrees of freedom
#AIC: 367.11
#
#Number of Fisher Scoring iterations: 2
#
#> unknown3tuk <- glht(unknown3glm, linfct = mcp(treatment = "Tukey"))
#> summary(unknown3tuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = unknown3 ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0   10.593      4.571   2.318   0.0534 .
#Virus - Control == 0    1.221      4.632   0.264   0.9624  
#Virus - dsRNA == 0     -9.373      4.321  -2.169   0.0766 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> unknown3tuk.cld <- cld(unknown3tuk)   # letter-based display
#> unknown3tuk.cld
#Control   dsRNA   Virus 
#"a"     "a"     "a" 
unknown3 <- summarySE(acng, measurevar="unknown3", groupvars=c("treatment"))
head(unknown3)
unknown3plot <- ggplot(unknown3, aes(treatment, unknown3, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=unknown3-se, ymax=unknown3+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
unknown3plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Unknown3") 

ggplot(acng, aes(x=factor(treatment), y=unknown3, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Unknown 3 (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)


unknown3.5glm<- glm(unknown3.5~treatment, data=acng)
summary(unknown3.5glm)
unknown3.5tuk <- glht(unknown3.5glm, linfct = mcp(treatment = "Tukey"))
summary(unknown3.5tuk)          # standard display
unknown3.5tuk.cld <- cld(unknown3.5tuk)   # letter-based display
unknown3.5tuk.cld
plot(unknown3.5tuk.cld, ylab="unknown3.5")
#> unknown3.5glm<- glm(unknown3.5~treatment, data=acng)
#> summary(unknown3.5glm)
#
#Call:
#  glm(formula = unknown3.5 ~ treatment, data = acng)
#
#Deviance Residuals: 
#  Min      1Q  Median      3Q     Max  
#-8.032  -1.196  -1.196   0.000  27.085  
#
#Coefficients:
#  Estimate Std. Error t value Pr(>|t|)   
#(Intercept)    3.143e-15  2.166e+00   0.000   1.0000   
#treatmentdsRNA 8.032e+00  2.877e+00   2.791   0.0078 **
#  treatmentVirus 1.196e+00  2.916e+00   0.410   0.6836   
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#
#(Dispersion parameter for gaussian family taken to be 60.99091)
#
#Null deviance: 3215.3  on 45  degrees of freedom
#Residual deviance: 2622.6  on 43  degrees of freedom
#AIC: 324.53
#
#Number of Fisher Scoring iterations: 2
#
#> unknown3.5tuk <- glht(unknown3.5glm, linfct = mcp(treatment = "Tukey"))
#> summary(unknown3.5tuk)          # standard display
#
#Simultaneous Tests for General Linear Hypotheses
#
#Multiple Comparisons of Means: Tukey Contrasts
#
#
#Fit: glm(formula = unknown3.5 ~ treatment, data = acng)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#dsRNA - Control == 0    8.032      2.877   2.791   0.0145 *
#  Virus - Control == 0    1.196      2.916   0.410   0.9113  
#Virus - dsRNA == 0     -6.835      2.720  -2.513   0.0322 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> unknown3.5tuk.cld <- cld(unknown3.5tuk)   # letter-based display
#> unknown3.5tuk.cld
#Control   dsRNA   Virus 
#"a"     "b"     "a" 
unknown3.5 <- summarySE(acng, measurevar="unknown3.5", groupvars=c("treatment"))
head(unknown3.5)
unknown3.5plot <- ggplot(unknown3.5, aes(treatment, unknown3.5, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=unknown3.5-se, ymax=unknown3.5+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
unknown3.5plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "NG - Unknown3.5") 

ggplot(acng, aes(x=factor(treatment), y=unknown3.5, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("Unknown 3.5 (ng)")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

unknown4glm<- glm(unknown4~treatment, data=acng)
summary(unknown4glm)
unknown4tuk <- glht(unknown4glm, linfct = mcp(treatment = "Tukey"))
summary(unknown4tuk)          # standard display
unknown4tuk.cld <- cld(unknown4tuk)   # letter-based display
unknown4tuk.cld
plot(unknown4tuk.cld, ylab="unknown4")


########################################
########################################
########################################
########################################
########################################
########################################
########################################
########################################

# bcppa = Bee-only compounds, Percentage peak area
bcppa <- read.csv("2017_OnlyBeeCompounds_PerPeakArea.csv", na.string="na", header=T);

#Convert column names to lower case
colnames(bcppa) <- tolower(colnames(bcppa))
colnames(bcppa)
View(bcppa)

# Rename "dsRNA" to "sham" for clarity
levels(bcppa$treatment)[levels(bcppa$treatment)=="Virus"] <- "IAPV"
##################################################################
### Compare percent peak area (pCompound) across compounds. 
library(multcomp) #for Tukey tests

phentriaconteneglm<- glm(phentriacontene~treatment, data=bcppa)
summary(phentriaconteneglm)

phentriacontenetuk <- glht(phentriaconteneglm, linfct = mcp(treatment = "Tukey"))
summary(phentriacontenetuk)          # standard display
phentriacontenetuk.cld <- cld(phentriacontenetuk)   # letter-based display
phentriacontenetuk.cld
plot(phentriacontenetuk.cld, ylab="pHentriacontene")


pmethylhentriacontaneglm<- glm(pmethylhentriacontane~treatment, data=bcppa)
summary(pmethylhentriacontaneglm)

pmethylhentriacontanetuk <- glht(pmethylhentriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylhentriacontanetuk)          # standard display
pmethylhentriacontanetuk.cld <- cld(pmethylhentriacontanetuk)   # letter-based display
pmethylhentriacontanetuk.cld
plot(pmethylhentriacontanetuk.cld, ylab="pMethylhentriacontane")

pmethylheptacosaneglm<- glm(pmethylheptacosane~treatment, data=bcppa)
summary(pmethylheptacosaneglm)

pmethylheptacosanetuk <- glht(pmethylheptacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylheptacosanetuk)          # standard display
pmethylheptacosanetuk.cld <- cld(pmethylheptacosanetuk)   # letter-based display
pmethylheptacosanetuk.cld
plot(pmethylheptacosanetuk.cld, ylab="pMethylheptacosane")
#Fit: glm(formula = pmethylheptacosane ~ treatment, data = bcppa)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0    0.1066     0.1177   0.905   0.6366  
#Virus - Control == 0  -0.1411     0.1193  -1.183   0.4630  
#Virus - Sham == 0     -0.2477     0.1113  -2.226   0.0666 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> pmethylheptacosanetuk.cld <- cld(pmethylheptacosanetuk)   # letter-based display
#> pmethylheptacosanetuk.cld
#Control    Sham   Virus 
#"a"     "a"     "a" 

pmethylheptacosane <- summarySE(bcppa, measurevar="pmethylheptacosane", groupvars=c("treatment"))
head(pmethylheptacosane)
pmethylheptacosaneplot <- ggplot(pmethylheptacosane, aes(treatment, pmethylheptacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=pmethylheptacosane-se, ymax=pmethylheptacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
pmethylheptacosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "BC-PPA - Methylheptacosane") 

ggplot(bcppa, aes(x=factor(treatment), y=pmethylheptacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Methyl-Heptacosane")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pmethylnonacosaneglm<- glm(pmethylnonacosane~treatment, data=bcppa)
summary(pmethylnonacosaneglm)

pmethylnonacosanetuk <- glht(pmethylnonacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylnonacosanetuk)          # standard display
pmethylnonacosanetuk.cld <- cld(pmethylnonacosanetuk)   # letter-based display
pmethylnonacosanetuk.cld
plot(pmethylnonacosanetuk.cld, ylab="pMethylnonacosane")

#Fit: glm(formula = pmethylnonacosane ~ treatment, data = bcppa)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0    0.6637     0.4632   1.433   0.3236  
#Virus - Control == 0  -0.5581     0.4694  -1.189   0.4595  
#Virus - Sham == 0     -1.2218     0.4379  -2.790   0.0144 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> pmethylnonacosanetuk.cld <- cld(pmethylnonacosanetuk)   # letter-based display
#> pmethylnonacosanetuk.cld
#Control    Sham   Virus 
#"ab"     "b"     "a" 
pmethylnonacosane <- summarySE(bcppa, measurevar="pmethylnonacosane", groupvars=c("treatment"))
head(pmethylnonacosane)
pmethylnonacosaneplot <- ggplot(pmethylnonacosane, aes(treatment, pmethylnonacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=pmethylnonacosane-se, ymax=pmethylnonacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
pmethylnonacosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "BC-PPA - Methylnonacosane") 

ggplot(bcppa, aes(x=factor(treatment), y=pmethylnonacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Methyl-Nonacosane")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pdocosaneglm<- glm(pdocosane~treatment, data=bcppa)
summary(pdocosaneglm)

pdocosanetuk <- glht(pdocosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pdocosanetuk)          # standard display
pdocosanetuk.cld <- cld(pdocosanetuk)   # letter-based display
pdocosanetuk.cld
plot(pdocosanetuk.cld, ylab="pdocosane")

peicosaneglm<- glm(peicosane~treatment, data=bcppa)
summary(peicosaneglm)

peicosanetuk <- glht(peicosaneglm, linfct = mcp(treatment = "Tukey"))
summary(peicosanetuk)          # standard display
peicosanetuk.cld <- cld(peicosanetuk)   # letter-based display
peicosanetuk.cld
plot(peicosanetuk.cld, ylab="peicosane")

pheneicosane1glm<- glm(pheneicosane1~treatment, data=bcppa)
summary(pheneicosane1glm)

pheneicosane1tuk <- glht(pheneicosane1glm, linfct = mcp(treatment = "Tukey"))
summary(pheneicosane1tuk)          # standard display
pheneicosane1tuk.cld <- cld(pheneicosane1tuk)   # letter-based display
pheneicosane1tuk.cld
plot(pheneicosane1tuk.cld, ylab="pheneicosane1")

# Fit: glm(formula = pheneicosane1 ~ treatment, data = bcppa)
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0    -4.195      1.747  -2.401   0.0431 *
#  Virus - Control == 0   -3.157      1.771  -1.783   0.1751  
#Virus - Sham == 0       1.038      1.652   0.629   0.8043  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> pheneicosane1tuk.cld <- cld(pheneicosane1tuk)   # letter-based display
#> pheneicosane1tuk.cld
#Control    Sham   Virus 
#"b"     "a"    "ab" 

pheneicosane1 <- summarySE(bcppa, measurevar="pheneicosane1", groupvars=c("treatment"))
head(pheneicosane1)
pheneicosane1plot <- ggplot(pheneicosane1, aes(treatment, pheneicosane1, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=pheneicosane1-se, ymax=pheneicosane1+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
pheneicosane1plot + labs(title = "Invader Cages 2017", x = "Treatment", y = "BC-PPA - Heneicosane1") 

ggplot(bcppa, aes(x=factor(treatment), y=pheneicosane1, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Heneicosane 1")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

pheneicosane2glm<- glm(pheneicosane2~treatment, data=bcppa)
summary(pheneicosane2glm)

pheneicosane2tuk <- glht(pheneicosane2glm, linfct = mcp(treatment = "Tukey"))
summary(pheneicosane2tuk)          # standard display
pheneicosane2tuk.cld <- cld(pheneicosane2tuk)   # letter-based display
pheneicosane2tuk.cld
plot(pheneicosane2tuk.cld, ylab="pheneicosane2")

phentriacontaneglm<- glm(phentriacontane~treatment, data=bcppa)
summary(phentriacontaneglm)

phentriacontanetuk <- glht(phentriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(phentriacontanetuk)          # standard display
phentriacontanetuk.cld <- cld(phentriacontanetuk)   # letter-based display
phentriacontanetuk.cld
plot(phentriacontanetuk.cld, ylab="phentriacontane")

pheptacosaneglm<- glm(pheptacosane~treatment, data=bcppa)
summary(pheptacosaneglm)

pheptacosanetuk <- glht(pheptacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pheptacosanetuk)          # standard display
pheptacosanetuk.cld <- cld(pheptacosanetuk)   # letter-based display
pheptacosanetuk.cld
plot(pheptacosanetuk.cld, ylab="pheptacosane")

phexacosaneglm<- glm(phexacosane~treatment, data=bcppa)
summary(phexacosaneglm)

phexacosanetuk <- glht(phexacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(phexacosanetuk)          # standard display
phexacosanetuk.cld <- cld(phexacosanetuk)   # letter-based display
phexacosanetuk.cld
plot(phexacosanetuk.cld, ylab="phexacosane")

phexadecenoicacidglm<- glm(phexadecenoicacid~treatment, data=bcppa)
summary(phexadecenoicacidglm)

phexadecenoicacidtuk <- glht(phexadecenoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(phexadecenoicacidtuk)          # standard display
phexadecenoicacidtuk.cld <- cld(phexadecenoicacidtuk)   # letter-based display
phexadecenoicacidtuk.cld
plot(phexadecenoicacidtuk.cld, ylab="phexadecenoicacid") # Change to hexadecenoic acid, 2019
#Fit: glm(formula = phexadecenoicacid ~ treatment, data = bcppa)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0   0.09788    0.18739   0.522   0.8603  
#Virus - Control == 0  0.47940    0.18991   2.524   0.0311 *
#  Virus - Sham == 0     0.38152    0.17715   2.154   0.0793 .
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> phexadecenoicacidtuk.cld <- cld(phexadecenoicacidtuk)   # letter-based display
#> phexadecenoicacidtuk.cld
#Control    Sham   Virus 
#"a"    "ab"     "b" 

phexadecenoicacid <- summarySE(bcppa, measurevar="phexadecenoicacid", groupvars=c("treatment"))
head(phexadecenoicacid)
phexadecenoicacidplot <- ggplot(phexadecenoicacid, aes(treatment, phexadecenoicacid, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=phexadecenoicacid-se, ymax=phexadecenoicacid+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
phexadecenoicacidplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "BC-PPA - Hexadecenoic Acid") 

ggplot(bcppa, aes(x=factor(treatment), y=phexadecenoicacid, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Hexadecenoic Acid")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

phexadecanoicacidglm<- glm(phexadecanoicacid~treatment, data=bcppa)
summary(phexadecanoicacidglm)

phexadecanoicacidtuk <- glht(phexadecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(phexadecanoicacidtuk)          # standard display
phexadecanoicacidtuk.cld <- cld(phexadecanoicacidtuk)   # letter-based display
phexadecanoicacidtuk.cld
plot(phexadecanoicacidtuk.cld, ylab="phexadecanoicacid")


phexadecanoicacidmethylester1glm<- glm(phexadecanoicacidmethylester1~treatment, data=bcppa)
summary(phexadecanoicacidmethylester1glm)

phexadecanoicacidmethylester1tuk <- glht(phexadecanoicacidmethylester1glm, linfct = mcp(treatment = "Tukey"))
summary(phexadecanoicacidmethylester1tuk)          # standard display
phexadecanoicacidmethylester1tuk.cld <- cld(phexadecanoicacidmethylester1tuk)   # letter-based display
phexadecanoicacidmethylester1tuk.cld
plot(phexadecanoicacidmethylester1tuk.cld, ylab="phexadecanoicacidmethylester1")

phexadecanoicacidmethylester2glm<- glm(phexadecanoicacidmethylester2~treatment, data=bcppa)
summary(phexadecanoicacidmethylester2glm)

phexadecanoicacidmethylester2tuk <- glht(phexadecanoicacidmethylester2glm, linfct = mcp(treatment = "Tukey"))
summary(phexadecanoicacidmethylester2tuk)          # standard display
phexadecanoicacidmethylester2tuk.cld <- cld(phexadecanoicacidmethylester2tuk)   # letter-based display
phexadecanoicacidmethylester2tuk.cld
plot(phexadecanoicacidmethylester2tuk.cld, ylab="phexadecanoicacidmethylester2")


pmethylheptadecanoicacidglm<- glm(pmethylheptadecanoicacid~treatment, data=bcppa)
summary(pmethylheptadecanoicacidglm)

pmethylheptadecanoicacidtuk <- glht(pmethylheptadecanoicacidglm, linfct = mcp(treatment = "Tukey"))
summary(pmethylheptadecanoicacidtuk)          # standard display
pmethylheptadecanoicacidtuk.cld <- cld(pmethylheptadecanoicacidtuk)   # letter-based display
pmethylheptadecanoicacidtuk.cld
plot(pmethylheptadecanoicacidtuk.cld, ylab="pmethylheptadecanoicacid")

pnonacosaneglm<- glm(pnonacosane~treatment, data=bcppa)
summary(pnonacosaneglm)

pnonacosanetuk <- glht(pnonacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(pnonacosanetuk)          # standard display
pnonacosanetuk.cld <- cld(pnonacosanetuk)   # letter-based display
pnonacosanetuk.cld
plot(pnonacosanetuk.cld, ylab="pnonacosane")

pnonadecaneglm<- glm(pnonadecane~treatment, data=bcppa)
summary(pnonadecaneglm)

pnonadecanetuk <- glht(pnonadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(pnonadecanetuk)          # standard display
pnonadecanetuk.cld <- cld(pnonadecanetuk)   # letter-based display
pnonadecanetuk.cld
plot(pnonadecanetuk.cld, ylab="pnonadecane")

pnonadeceneglm<- glm(pnonadecene~treatment, data=bcppa)
summary(pnonadeceneglm)

pnonadecenetuk <- glht(pnonadeceneglm, linfct = mcp(treatment = "Tukey"))
summary(pnonadecenetuk)          # standard display
pnonadecenetuk.cld <- cld(pnonadecenetuk)   # letter-based display
pnonadecenetuk.cld
plot(pnonadecenetuk.cld, ylab="pnonadecene")

poctadecaneglm<- glm(poctadecane~treatment, data=bcppa)
summary(poctadecaneglm)

poctadecanetuk <- glht(poctadecaneglm, linfct = mcp(treatment = "Tukey"))
summary(poctadecanetuk)          # standard display
poctadecanetuk.cld <- cld(poctadecanetuk)   # letter-based display
poctadecanetuk.cld
plot(poctadecanetuk.cld, ylab="poctadecane")

poctacosaneglm<- glm(poctacosane~treatment, data=bcppa)
summary(poctacosaneglm)

poctacosanetuk <- glht(poctacosaneglm, linfct = mcp(treatment = "Tukey"))
summary(poctacosanetuk)          # standard display
poctacosanetuk.cld <- cld(poctacosanetuk)   # letter-based display
poctacosanetuk.cld
plot(poctacosanetuk.cld, ylab="poctacosane")
#Fit: glm(formula = poctacosane ~ treatment, data = bcppa)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0    0.7136     0.5514   1.294   0.3982  
#Virus - Control == 0  -0.5235     0.5588  -0.937   0.6168  
#Virus - Sham == 0     -1.2371     0.5213  -2.373   0.0463 *
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> poctacosanetuk.cld <- cld(poctacosanetuk)   # letter-based display
#> poctacosanetuk.cld
#Control    Sham   Virus 
#"ab"     "b"     "a" 

poctacosane <- summarySE(bcppa, measurevar="poctacosane", groupvars=c("treatment"))
head(poctacosane)
poctacosaneplot <- ggplot(poctacosane, aes(treatment, poctacosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=poctacosane-se, ymax=poctacosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
poctacosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "BC-PPA - Octacosane") 

ggplot(bcppa, aes(x=factor(treatment), y=poctacosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Octacosane")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)

poleicacid1glm<- glm(poleicacid1~treatment, data=bcppa)
summary(poleicacid1glm)

poleicacid1tuk <- glht(poleicacid1glm, linfct = mcp(treatment = "Tukey"))
summary(poleicacid1tuk)          # standard display
poleicacid1tuk.cld <- cld(poleicacid1tuk)   # letter-based display
poleicacid1tuk.cld
plot(poleicacid1tuk.cld, ylab="poleicacid1")

poleicacid2glm<- glm(poleicacid2~treatment, data=bcppa)
summary(poleicacid2glm)

poleicacid2tuk <- glht(poleicacid2glm, linfct = mcp(treatment = "Tukey"))
summary(poleicacid2tuk)          # standard display
poleicacid2tuk.cld <- cld(poleicacid2tuk)   # letter-based display
poleicacid2tuk.cld
plot(poleicacid2tuk.cld, ylab="poleicacid2")

poleicacid3glm<- glm(poleicacid3~treatment, data=bcppa)
summary(poleicacid3glm)

poleicacid3tuk <- glht(poleicacid3glm, linfct = mcp(treatment = "Tukey"))
summary(poleicacid3tuk)          # standard display
poleicacid3tuk.cld <- cld(poleicacid3tuk)   # letter-based display
poleicacid3tuk.cld
plot(poleicacid3tuk.cld, ylab="poleicacid3")


ptetracosaneglm<- glm(ptetracosane~treatment, data=bcppa)
summary(ptetracosaneglm)

ptetracosanetuk <- glht(ptetracosaneglm, linfct = mcp(treatment = "Tukey"))
summary(ptetracosanetuk)          # standard display
ptetracosanetuk.cld <- cld(ptetracosanetuk)   # letter-based display
ptetracosanetuk.cld
plot(ptetracosanetuk.cld, ylab="ptetracosane")

ptriacontane1glm<- glm(ptriacontane1~treatment, data=bcppa)
summary(ptriacontane1glm)

ptriacontane1tuk <- glht(ptriacontane1glm, linfct = mcp(treatment = "Tukey"))
summary(ptriacontane1tuk)          # standard display
ptriacontane1tuk.cld <- cld(ptriacontane1tuk)   # letter-based display
ptriacontane1tuk.cld
plot(ptriacontane1tuk.cld, ylab="ptriacontane1")

ptriacontane2glm<- glm(ptriacontane2~treatment, data=bcppa)
summary(ptriacontane2glm)

ptriacontane2tuk <- glht(ptriacontane2glm, linfct = mcp(treatment = "Tukey"))
summary(ptriacontane2tuk)          # standard display
ptriacontane2tuk.cld <- cld(ptriacontane2tuk)   # letter-based display
ptriacontane2tuk.cld
plot(ptriacontane2tuk.cld, ylab="ptriacontane2")

ptricosaneglm<- glm(ptricosane~treatment, data=bcppa)
summary(ptricosaneglm)

ptricosanetuk <- glht(ptricosaneglm, linfct = mcp(treatment = "Tukey"))
summary(ptricosanetuk)          # standard display
ptricosanetuk.cld <- cld(ptricosanetuk)   # letter-based display
ptricosanetuk.cld
plot(ptricosanetuk.cld, ylab="ptricosane")

#Fit: glm(formula = ptricosane ~ treatment, data = bcppa)
#
#Linear Hypotheses:
#  Estimate Std. Error z value Pr(>|z|)  
#Sham - Control == 0    -5.878      2.757  -2.132   0.0834 .
#Virus - Control == 0   -2.497      2.795  -0.894   0.6442  
#Virus - Sham == 0       3.381      2.607   1.297   0.3965  
#---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Adjusted p values reported -- single-step method)
#
#> ptricosanetuk.cld <- cld(ptricosanetuk)   # letter-based display
#> ptricosanetuk.cld
#Control    Sham   Virus 
#"a"     "a"     "a" 
ptricosane <- summarySE(bcppa, measurevar="ptricosane", groupvars=c("treatment"))
head(ptricosane)
ptricosaneplot <- ggplot(ptricosane, aes(treatment, ptricosane, label = treatment)) + 
  geom_bar(aes(fill=treatment), colour="black", position=position_dodge(),stat="identity") +   
  scale_fill_manual(name = "Treatment", labels = c("Sham", "Control", "Virus"), values=c("lightskyblue","palegreen", "mediumpurple")) +
  geom_errorbar(aes(ymin=ptricosane-se, ymax=ptricosane+se),
                width=.2,                    # Width of the error bars
                position=position_dodge(.9)) +
  theme_minimal() 
ptricosaneplot + labs(title = "Invader Cages 2017", x = "Treatment", y = "BC-PPA - Tricosane") 

ggplot(bcppa, aes(x=factor(treatment), y=ptricosane, fill=treatment, alpha=0.2)) +
  geom_violin()+theme_classic() +
  ylab("PPA - Tricosane")+xlab("") +
  geom_boxplot(width=.1, outlier.colour=NA)


ptricosene1glm<- glm(ptricosene1~treatment, data=bcppa)
summary(ptricosene1glm)

ptricosene1tuk <- glht(ptricosene1glm, linfct = mcp(treatment = "Tukey"))
summary(ptricosene1tuk)          # standard display
ptricosene1tuk.cld <- cld(ptricosene1tuk)   # letter-based display
ptricosene1tuk.cld
plot(ptricosene1tuk.cld, ylab="ptricosene1")

ptricosene2glm<- glm(ptricosene2~treatment, data=bcppa)
summary(ptricosene2glm)

ptricosene2tuk <- glht(ptricosene2glm, linfct = mcp(treatment = "Tukey"))
summary(ptricosene2tuk)          # standard display
ptricosene2tuk.cld <- cld(ptricosene2tuk)   # letter-based display
ptricosene2tuk.cld
plot(ptricosene2tuk.cld, ylab="ptricosene2")

ptritriacontaneglm<- glm(ptritriacontane~treatment, data=bcppa)
summary(ptritriacontaneglm)

ptritriacontanetuk <- glht(ptritriacontaneglm, linfct = mcp(treatment = "Tukey"))
summary(ptritriacontanetuk)          # standard display
ptritriacontanetuk.cld <- cld(ptritriacontanetuk)   # letter-based display
ptritriacontanetuk.cld
plot(ptritriacontanetuk.cld, ylab="ptritriacontane")

########################
########################
########################
########################
########################
########################
# LDA - All compounds, nanogram amount
library(ggplot2)
library(stats)
library(lme4)
library(MASS)
library(car)
library(scales)
library(gridExtra)

# bcnglda = only compounds found in bee literature, ng of each
bcnglda <- read.csv("2017_BeeCompoundsForLDA.csv", na.string="na", header=T)
colnames(bcnglda) <- tolower(colnames(bcnglda))
colnames(bcnglda)

t.bcnglda <- t(bcnglda); # t() is a matrix transposition function
t.bcnglda[1:5,1:5];

dim(t.bcnglda)  # describes the matrix dimensions
#[1] 47 32

bcnglda2 <- read.csv("2017_BeeCompoundsForLDA.csv", na.string="na",skip=1, header=F);
## skips the first two rows (in this case, the ID row and group row)
colnames(bcnglda2) <- names(bcnglda)
## puts header row back on indiv.wasp2 (e.g. the id and individual name), while skipping the group row
t.bcnglda2 <- t(bcnglda2)
t.bcnglda2[1:5,1:5];
bcnglda2[1:5,1:5];

bcnglda2.d <- data.frame(t(bcnglda2)) # changes transposed matrix into a dataframe
names(bcnglda2.d) <- bcnglda2$sample # gives columns names from gene IDs ("id" in indiv.wasp2)
treatn <- t.bcnglda[-1,1] #creates the group column
treat <- as.factor(as.vector(treatn)) # makes the numerical values for treatment become strings

bcnglda2.d2 <- bcnglda2.d[-c(1), ]
#bcnglda2.d3 <- cbind(treat,bcnglda2.d2) # adds group ID column (as factor)
#View(bcnglda2.d3)

##############################
# I just need bcnglda2.d2
colnames(bcnglda2.d2)
## we see that this converts our p columns to factors - need to revert to numeric
bcnglda2.d2$Hentriacontene <- as.numeric(as.character(bcnglda2.d2$Hentriacontene))
class(bcnglda2.d2$Hentriacontene)

bcnglda2.d2$MethylHentriacontane <- as.numeric(as.character(bcnglda2.d2$MethylHentriacontane))
class(bcnglda2.d2$MethylHentriacontane)

bcnglda2.d2$MethylHeptacosane <- as.numeric(as.character(bcnglda2.d2$MethylHeptacosane))
class(bcnglda2.d2$MethylHeptacosane)

bcnglda2.d2$MethylNonacosane <- as.numeric(as.character(bcnglda2.d2$MethylNonacosane))
class(bcnglda2.d2$MethylNonacosane)

bcnglda2.d2$Docosane <- as.numeric(as.character(bcnglda2.d2$Docosane))
class(bcnglda2.d2$Docosane)

bcnglda2.d2$Eicosane <- as.numeric(as.character(bcnglda2.d2$Eicosane))
class(bcnglda2.d2$Eicosane)

bcnglda2.d2$Heneicosane1 <- as.numeric(as.character(bcnglda2.d2$Heneicosane1))
class(bcnglda2.d2$Heneicosane1)

bcnglda2.d2$Heneicosane2 <- as.numeric(as.character(bcnglda2.d2$Heneicosane2))
class(bcnglda2.d2$Heneicosane2)

bcnglda2.d2$Hentriacontane <- as.numeric(as.character(bcnglda2.d2$Hentriacontane))
class(bcnglda2.d2$Hentriacontane)

bcnglda2.d2$Heptacosane <- as.numeric(as.character(bcnglda2.d2$Heptacosane))
class(bcnglda2.d2$Heptacosane)

bcnglda2.d2$Hexacosane <- as.numeric(as.character(bcnglda2.d2$Hexacosane))
class(bcnglda2.d2$Hexacosane)

bcnglda2.d2$HexadecanoicAcid1 <- as.numeric(as.character(bcnglda2.d2$HexadecanoicAcid1))
class(bcnglda2.d2$HexadecanoicAcid1)

bcnglda2.d2$HexadecanoicAcid2 <- as.numeric(as.character(bcnglda2.d2$HexadecanoicAcid2))
class(bcnglda2.d2$HexadecanoicAcid2)

bcnglda2.d2$HexadecanoicAcidMethylEster1 <- as.numeric(as.character(bcnglda2.d2$HexadecanoicAcidMethylEster1))
class(bcnglda2.d2$HexadecanoicAcidMethylEster1)

bcnglda2.d2$HexadecanoicAcidMethylEster2 <- as.numeric(as.character(bcnglda2.d2$HexadecanoicAcidMethylEster2))
class(bcnglda2.d2$HexadecanoicAcidMethylEster2)

bcnglda2.d2$MethylheptadecanoicAcid <- as.numeric(as.character(bcnglda2.d2$MethylheptadecanoicAcid))
class(bcnglda2.d2$MethylheptadecanoicAcid)

bcnglda2.d2$Nonacosane <- as.numeric(as.character(bcnglda2.d2$Nonacosane))
class(bcnglda2.d2$Nonacosane)

bcnglda2.d2$Nonadecane <- as.numeric(as.character(bcnglda2.d2$Nonadecane))
class(bcnglda2.d2$Nonadecane)

bcnglda2.d2$Nonadecene <- as.numeric(as.character(bcnglda2.d2$Nonadecene))
class(bcnglda2.d2$Nonadecene)

bcnglda2.d2$Octadecane <- as.numeric(as.character(bcnglda2.d2$Octadecane))
class(bcnglda2.d2$Octadecane)

bcnglda2.d2$Octacosane <- as.numeric(as.character(bcnglda2.d2$Octacosane))
class(bcnglda2.d2$Octacosane)

bcnglda2.d2$OleicAcid1 <- as.numeric(as.character(bcnglda2.d2$OleicAcid1))
class(bcnglda2.d2$OleicAcid1)

bcnglda2.d2$OleicAcid2 <- as.numeric(as.character(bcnglda2.d2$OleicAcid2))
class(bcnglda2.d2$OleicAcid2)

bcnglda2.d2$OleicAcid3 <- as.numeric(as.character(bcnglda2.d2$OleicAcid3))
class(bcnglda2.d2$OleicAcid3)

bcnglda2.d2$Tetracosane <- as.numeric(as.character(bcnglda2.d2$Tetracosane))
class(bcnglda2.d2$Tetracosane)

bcnglda2.d2$Triacontane1 <- as.numeric(as.character(bcnglda2.d2$Triacontane1))
class(bcnglda2.d2$Triacontane1)

bcnglda2.d2$Triacontane2 <- as.numeric(as.character(bcnglda2.d2$Triacontane2))
class(bcnglda2.d2$Triacontane2)

bcnglda2.d2$Tricosane <- as.numeric(as.character(bcnglda2.d2$Tricosane))
class(bcnglda2.d2$Tricosane)

bcnglda2.d2$Tricosene1 <- as.numeric(as.character(bcnglda2.d2$Tricosene1))
class(bcnglda2.d2$Tricosene1)

bcnglda2.d2$Tricosene2 <- as.numeric(as.character(bcnglda2.d2$Tricosene2))
class(bcnglda2.d2$Tricosene2)

bcnglda2.d2$Tritriacontane <- as.numeric(as.character(bcnglda2.d2$Tritriacontane))
class(bcnglda2.d2$Tritriacontane)

# Conduct the LDA
bcngldalda <- lda(Treatment~., data=bcnglda2.d2)
summary(bcngldalda)
bcngldalda

bcngldalda <- lda(Treatment~., data=bcnglda2.d2)
summary(bcngldalda)
bcngldalda
bcngldalda$scaling

plot(bcngldalda, 
     panel = function(x, y, ...) {
       points(x, y, ...)
       text(x,y,labels=bcnglda2.d2$Treatment, ...)
     }
     ,
     col = as.integer(bcnglda2.d2$Treatment), pch = 20)

# Shows distribution of prediction locales - https://rpubs.com/ifn1411/LDA
bcnglda.lda.values <- predict(bcngldalda)
ldahist(bcnglda.lda.values$x[,1], g = treat)

plot(bcnglda.lda.values$x[,1], bcnglda.lda.values$x[,2])
text(bcnglda.lda.values$x[,1], bcnglda.lda.values$x[,2], 
     treat, cex = 1, pch = as.integer(treat), pos = 4, col = as.integer(treat))

# Visualize LDA
bcngldadf <- data.frame(treat, lda = bcnglda.lda.values$x)
ggplot(bcngldadf) + geom_point(aes(lda.LD1, lda.LD2, colour = treat), size = 2.5) +
  scale_color_manual(values=c("#0066FF", "#00FF33", "#9933FF"), 
                     name="Treatment",
                     breaks=c("Control", "dsRNA", "Virus"),
                     labels=c("Control", "Sham", "Virus")) +   
  scale_x_continuous(name="LD1") +
  scale_y_continuous(name="LD2") + 
  ggtitle("Bee compounds, Nanogram")


######################
# Bee-only compounds - Percent peak area
# ldabcppa = Percentage peak area for only compounds found in bee lit
ldabcppa <- read.csv("2017_BeeCompoundsPPA_ForLDA.csv", na.string="na", header=T, fileEncoding="UTF-8", skipNul = TRUE)
#Convert column names to lower case
colnames(ldabcppa) <- tolower(colnames(ldabcppa))
colnames(ldabcppa)

t.ldabcppa <- t(ldabcppa); # t() is a matrix transposition function
t.ldabcppa[1:5,1:5];

dim(t.ldabcppa)  # describes the matrix dimensions
#[1] 47 32

ldabcppa2 <- read.csv("2017_BeeCompoundsPPA_ForLDA.csv", na.string="na",skip=1, header=F);
## skips the first two rows (in this case, the ID row and group row)
colnames(ldabcppa2) <- names(ldabcppa)
## puts header row back on indiv.wasp2 (e.g. the id and individual name), while skipping the group row
t.ldabcppa2 <- t(ldabcppa2)
t.ldabcppa2[1:5,1:5];
ldabcppa2[1:5,1:5];

ldabcppa2.d <- data.frame(t(ldabcppa2)) # changes transposed matrix into a dataframe

names(ldabcppa2.d) <- ldabcppa2$sample # gives columns names from gene IDs ("id" in indiv.wasp2)
treatn <- t.ldabcppa[-1,1] #creates the group column
treat <- as.factor(as.vector(treatn)) # makes the numerical values for treatment become strings

ldabcppa2.d2 <- ldabcppa2.d[-c(1), ]

ldabcppa2.d3 <- cbind(treat,ldabcppa2.d2) # adds group ID column (as factor)

##############################
# I just need ldabcppa2.d2
colnames(ldabcppa2.d2)

## we see that this converts our p columns to factors - need to revert to numeric
ldabcppa2.d2$pHentriacontene <- as.numeric(as.character(ldabcppa2.d2$pHentriacontene))
class(ldabcppa2.d2$pHentriacontene)

ldabcppa2.d2$pMethylHentriacontane <- as.numeric(as.character(ldabcppa2.d2$pMethylHentriacontane))
class(ldabcppa2.d2$pMethylHentriacontane)

ldabcppa2.d2$pMethylHeptacosane <- as.numeric(as.character(ldabcppa2.d2$pMethylHeptacosane))
class(ldabcppa2.d2$pMethylHeptacosane)

ldabcppa2.d2$pMethylNonacosane <- as.numeric(as.character(ldabcppa2.d2$pMethylNonacosane))
class(ldabcppa2.d2$pMethylNonacosane)

ldabcppa2.d2$pDocosane <- as.numeric(as.character(ldabcppa2.d2$pDocosane))
class(ldabcppa2.d2$pDocosane)

ldabcppa2.d2$pEicosane <- as.numeric(as.character(ldabcppa2.d2$pEicosane))
class(ldabcppa2.d2$pEicosane)

ldabcppa2.d2$pHeneicosane1 <- as.numeric(as.character(ldabcppa2.d2$pHeneicosane1))
class(ldabcppa2.d2$pHeneicosane1)

ldabcppa2.d2$pHeneicosane2 <- as.numeric(as.character(ldabcppa2.d2$pHeneicosane2))
class(ldabcppa2.d2$pHeneicosane2)

ldabcppa2.d2$pHentriacontane <- as.numeric(as.character(ldabcppa2.d2$pHentriacontane))
class(ldabcppa2.d2$pHentriacontane)

ldabcppa2.d2$pHeptacosane <- as.numeric(as.character(ldabcppa2.d2$pHeptacosane))
class(ldabcppa2.d2$pHeptacosane)

ldabcppa2.d2$pHexacosane <- as.numeric(as.character(ldabcppa2.d2$pHexacosane))
class(ldabcppa2.d2$pHexacosane)

ldabcppa2.d2$pHexadecanoicAcid1 <- as.numeric(as.character(ldabcppa2.d2$pHexadecanoicAcid1))
class(ldabcppa2.d2$pHexadecanoicAcid1)

ldabcppa2.d2$pHexadecanoicAcid2 <- as.numeric(as.character(ldabcppa2.d2$pHexadecanoicAcid2))
class(ldabcppa2.d2$pHexadecanoicAcid2)

ldabcppa2.d2$pHexadecanoicAcidMethylEster1 <- as.numeric(as.character(ldabcppa2.d2$pHexadecanoicAcidMethylEster1))
class(ldabcppa2.d2$pHexadecanoicAcidMethylEster1)

ldabcppa2.d2$pHexadecanoicAcidMethylEster2 <- as.numeric(as.character(ldabcppa2.d2$pHexadecanoicAcidMethylEster2))
class(ldabcppa2.d2$pHexadecanoicAcidMethylEster2)

ldabcppa2.d2$pMethylheptadecanoicAcid <- as.numeric(as.character(ldabcppa2.d2$pMethylheptadecanoicAcid))
class(ldabcppa2.d2$pMethylheptadecanoicAcid)

ldabcppa2.d2$pNonacosane <- as.numeric(as.character(ldabcppa2.d2$pNonacosane))
class(ldabcppa2.d2$pNonacosane)

ldabcppa2.d2$pNonadecane <- as.numeric(as.character(ldabcppa2.d2$pNonadecane))
class(ldabcppa2.d2$pNonadecane)

ldabcppa2.d2$pNonadecene <- as.numeric(as.character(ldabcppa2.d2$pNonadecene))
class(ldabcppa2.d2$pNonadecene)

ldabcppa2.d2$pOctadecane <- as.numeric(as.character(ldabcppa2.d2$pOctadecane))
class(ldabcppa2.d2$pOctadecane)

ldabcppa2.d2$pOctacosane <- as.numeric(as.character(ldabcppa2.d2$pOctacosane))
class(ldabcppa2.d2$pOctacosane)

ldabcppa2.d2$pOleicAcid1 <- as.numeric(as.character(ldabcppa2.d2$pOleicAcid1))
class(ldabcppa2.d2$pOleicAcid1)

ldabcppa2.d2$pOleicAcid2 <- as.numeric(as.character(ldabcppa2.d2$pOleicAcid2))
class(ldabcppa2.d2$pOleicAcid2)

ldabcppa2.d2$pOleicAcid3 <- as.numeric(as.character(ldabcppa2.d2$pOleicAcid3))
class(ldabcppa2.d2$pOleicAcid3)

ldabcppa2.d2$pTetracosane <- as.numeric(as.character(ldabcppa2.d2$pTetracosane))
class(ldabcppa2.d2$pTetracosane)

ldabcppa2.d2$pTriacontane1 <- as.numeric(as.character(ldabcppa2.d2$pTriacontane1))
class(ldabcppa2.d2$pTriacontane1)

ldabcppa2.d2$pTriacontane2 <- as.numeric(as.character(ldabcppa2.d2$pTriacontane2))
class(ldabcppa2.d2$pTriacontane2)

ldabcppa2.d2$pTricosane <- as.numeric(as.character(ldabcppa2.d2$pTricosane))
class(ldabcppa2.d2$pTricosane)

ldabcppa2.d2$pTricosene1 <- as.numeric(as.character(ldabcppa2.d2$pTricosene1))
class(ldabcppa2.d2$pTricosene1)

ldabcppa2.d2$pTricosene2 <- as.numeric(as.character(ldabcppa2.d2$pTricosene2))
class(ldabcppa2.d2$pTricosene2)

ldabcppa2.d2$pTritriacontane <- as.numeric(as.character(ldabcppa2.d2$pTritriacontane))
class(ldabcppa2.d2$pTritriacontane)

## Run the LDA
ldabcppalda <- lda(Treatment~., data=ldabcppa2.d2)
summary(ldabcppalda)
ldabcppalda
ldabcppalda$scaling

plot(ldabcppalda, 
     panel = function(x, y, ...) {
       points(x, y, ...)
       text(x,y,labels=ldabcppa2.d2$Treatment, ...)
     }
     ,
     col = as.integer(ldabcppa2.d2$Treatment), pch = 20)

# Shows distribution of prediction locales - https://rpubs.com/ifn1411/LDA
ldabcppa.lda.values <- predict(ldabcppalda)
ldahist(ldabcppa.lda.values$x[,1], g = treat)

plot(ldabcppa.lda.values$x[,1], ldabcppa.lda.values$x[,2])
text(ldabcppa.lda.values$x[,1], ldabcppa.lda.values$x[,2], 
     treat, cex = 1, pch = as.integer(treat), pos = 4, col = as.integer(treat))

#Visualize the LDA
ldabcppadf <- data.frame(treat, lda = ldabcppa.lda.values$x)
ggplot(ldabcppadf) + geom_point(aes(lda.LD1, lda.LD2, colour = treat), size = 2.5) +
  scale_color_manual(values=c("#0066FF", "#00FF33", "#9933FF"), 
                     name="Treatment",
                     breaks=c("Control", "dsRNA", "Virus"),
                     labels=c("Control", "Sham", "Virus")) +   
  scale_x_continuous(name="LD1") +
  scale_y_continuous(name="LD2") + 
  ggtitle("Bee-only compounds, Percent Peak Area")

